<?php

if ( ! function_exists( 'reign_xprofile_cover_image' ) ) {

	function reign_xprofile_cover_image( $settings = array() ) {
		global $wbtm_reign_settings;
		$default_xprofile_cover_image_size = isset( $wbtm_reign_settings['reign_buddyextender']['default_xprofile_cover_image_size'] ) ? $wbtm_reign_settings['reign_buddyextender']['default_xprofile_cover_image_size'] : '';

		/* changing default user avatar */
		$avatar_default_image = isset( $settings['reign_buddyextender']['avatar_default_image_id'] ) ? $settings['reign_buddyextender']['avatar_default_image_id'] : '';
		if ( ! empty( $avatar_default_image ) ) {
			$settings['default_cover'] = $avatar_default_image;
		}
		/* changing default user avatar */

		if ( empty( $default_xprofile_cover_image_size ) ) {
			$settings['width']  = 1750;
			$settings['height'] = 450;
		}
		return $settings;
	}

	// add_filter( 'bp_before_xprofile_cover_image_settings_parse_args', 'reign_xprofile_cover_image', 10, 1 );
}

/* Get User online */
if ( ! function_exists( 'reign_is_user_online' ) ) {

	/**
	 * Check if a Buddypress member is online or not
	 *
	 * @global object $wpdb
	 * @param  integer $user_id
	 * @param  integer $time
	 * @return boolean
	 */
	function reign_is_user_online() {
		global $members_template;
		$member_last_activity = strtotime( $members_template->member->last_activity );
		$current_time         = current_time( 'U' );
		$diff                 = (int) abs( $member_last_activity - $current_time );

		if ( ! empty( $diff ) && $diff <= MINUTE_IN_SECONDS * 5 ) {
			return true;
		} else {
			return false;
		}
	}
}

/* Get User online */
if ( ! function_exists( 'reign_is_user_away' ) ) {

	/**
	 * Check if a Buddypress member is online or not
	 *
	 * @global object $wpdb
	 * @param  integer $user_id
	 * @param  integer $time
	 * @return boolean
	 */
	function reign_is_user_away() {
		global $members_template;
		$member_last_activity = strtotime( $members_template->member->last_activity );
		$current_time         = current_time( 'U' );
		$diff                 = (int) abs( $member_last_activity - $current_time );

		if ( ! empty( $diff ) && $diff >= MINUTE_IN_SECONDS * 5 && $diff <= MINUTE_IN_SECONDS * 30 ) {
			return true;
		} else {
			return false;
		}
	}
}


if ( ! function_exists( 'reign_get_online_status' ) ) {

	function reign_get_online_status( $user_id ) {
		$output = '';
		if ( reign_is_user_online() ) {
			$output = '<span class="reign-status online"></span>';
		} elseif ( reign_is_user_away() ) {
			$output = '<span class="reign-status away"></span>';
		} else {
			$output = '<span class="reign-status offline"></span>';
		}
		return $output;
	}
}


if ( ! function_exists( 'reign_get_group_member_count' ) ) {

	function reign_get_group_member_count() {
		global $groups_template;
		if ( isset( $groups_template->group->total_member_count ) ) {
			echo '<span class="group-count">' . (int) $groups_template->group->total_member_count . '</span>';
		}
	}
}

if ( ! function_exists( 'reign_bp_get_group_type' ) ) {

	function reign_bp_get_group_type( $group = false ) {
		global $groups_template;

		if ( empty( $group ) ) {
			$group = & $groups_template->group;
		}

		if ( 'public' == $group->status ) {
			$type = __( 'Public', 'reign' );
		} elseif ( 'hidden' == $group->status ) {
			$type = __( 'Hidden', 'reign' );
		} elseif ( 'private' == $group->status ) {
			$type = __( 'Private', 'reign' );
		} else {
			$type = ucwords( $group->status ) . ' ' . __( 'Group', 'reign' );
		}

		return '<span class="group-type ' . $group->status . '">' . $type . '</span>';
	}
}

/**
 * Output markup listing group admins.
 *
 * @since 1.0.0
 *
 * @param object|bool $group Optional. Group object.
 *                           Default: current group in loop.
 */
function reign_bp_group_list_admins( $group = false ) {
	global $groups_template;

	if ( empty( $group ) ) {
		$group = & $groups_template->group;
	}

	if ( ! empty( $group->admins ) ) {
		$i = 0;
		?>
	<ul id="group-admins">
		<?php foreach ( (array) $group->admins as $admin ) { ?>
				<li class="group-admin-item">
					<a href="<?php echo esc_url( bp_core_get_user_domain( $admin->user_id, $admin->user_nicename, $admin->user_login ) ); ?>">
			<?php
			echo bp_core_fetch_avatar( // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
				array(
					'item_id' => $admin->user_id,
					'email'   => $admin->user_email,
					'alt'     => sprintf( __( 'Profile picture of %s', 'reign' ), bp_core_get_user_displayname( $admin->user_id ) ),
				)
			);
			?>
					</a>
					<div class="group-admin-meta">
						<span class="group-by"><?php esc_html_e( 'Created by', 'reign' ); ?></span>
						<span class="admin-name"><a href="<?php echo bp_core_get_user_domain( $admin->user_id, $admin->user_nicename, $admin->user_login ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?>"><?php echo bp_core_get_user_displayname( $admin->user_id ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?></a></span>
					</div>
				</li>
				<?php
				$i++;
				if ( $i == 1 ) {
					break;
				}
		}
		?>
	</ul>
	<?php } else { ?>
		<span class="activity"><?php esc_html_e( 'No Admins', 'reign' ); ?></span>
														<?php
	}
}

if ( ! function_exists( 'reign_group_index_widgets' ) ) {

	function reign_group_index_widgets() {
		get_template_part( 'template-parts/groups-widgets' );
	}

	add_action( 'reign_begin_group_index_sidebar', 'reign_group_index_widgets' );
}

if ( ! function_exists( 'reign_member_index_widgets' ) ) {

	function reign_member_index_widgets() {
		get_template_part( 'template-parts/members-widgets' );
	}

	add_action( 'reign_begin_member_index_sidebar', 'reign_member_index_widgets' );
}

/*
 * Hide bp dir vertical nav related class on activity page
 */
add_filter( 'bp_nouveau_get_container_classes', 'reign_bp_nouveau_get_container_classes', 99, 2 );
function reign_bp_nouveau_get_container_classes( $class, $classes ) {
	$component = bp_current_component();

	if ( $component == 'activity' && bp_is_directory() && ! bp_is_user() && ! bp_is_group() ) {
		$class  = str_replace( 'bp-dir-vert-nav', '', $class );
		$class  = str_replace( 'bp-vertical-navs', '', $class );
		$class .= ' bp-dir-hori-nav ';
	}
	return $class;
}

/**
 * Function to filter activity content to formate some types of activity
 *
 * @var void
 */
add_filter( 'bp_activity_entry_content', 'reign_filter_activity_content', 9 );
add_action( 'bp_activity_embed_after_media', 'reign_filter_activity_content' );
function reign_filter_activity_content() {
	if ( ! bp_activity_has_content() ) {
		global $activities_template;

		$activity_id   = $activities_template->activity->id;
		$activity_type = $activities_template->activity->type;

		if ( function_exists( 'buddypress' ) && isset( buddypress()->buddyboss ) && $activity_type == 'new_avatar' ) {
			return;
		}

		if ( function_exists( 'buddypress' ) && version_compare( buddypress()->version, '10.0.0', '>=' ) && ! isset( buddypress()->buddyboss ) && $activity_type != 'new_group_avatar' && $activity_type != 'new_group_cover_photo' && $activity_type != 'new_cover_photo' ) {
			return;
		}

		switch ( $activity_type ) {
			case 'joined_group':
				reign_joined_group_activity_content( $activities_template->activity );
				break;
			case 'friendship_created':
				reign_friendship_created_activity_content( $activities_template->activity );
				break;
			case 'new_group_avatar':
			case 'new_group_cover_photo':
				reign_new_group_avatar_activity_content( $activities_template->activity );
				break;
			case 'new_avatar':
			case 'new_cover_photo':
				reign_new_avatar_activity_content( $activities_template->activity );
				break;
			default:
				break;
		}
	}

}

/**
 * Formate join group activity.
 *
 * @param  object $activity
 *
 * @return void
 */
function reign_joined_group_activity_content( $activity ) {
	$args = array(
		'activity_id' => $activity->id,
		'user_id'     => $activity->user_id,
		'item_id'     => $activity->item_id,
		'component'   => $activity->component,
		'type'        => $activity->type,
	);

	if ( ! class_exists( 'Youzify' ) ) {
		get_template_part( 'template-parts/content', 'user-preview', $args );
	}
}

/**
 * Formate friendship created activity
 *
 * @param  object $activity
 *
 * @return void
 */
function reign_friendship_created_activity_content( $activity ) {

	$args = array(
		'activity_id'       => $activity->id,
		'user_id'           => $activity->user_id,
		'item_id'           => $activity->item_id,
		'secondary_item_id' => $activity->secondary_item_id,
		'component'         => $activity->component,
		'type'              => $activity->type,
	);

	if ( ! class_exists( 'Youzify' ) ) {
		get_template_part( 'template-parts/content', 'user-preview', $args );
	}
}

function reign_new_avatar_activity_content( $activity ) {

	$args = array(
		'activity_id'       => $activity->id,
		'user_id'           => $activity->user_id,
		'item_id'           => $activity->item_id,
		'secondary_item_id' => $activity->secondary_item_id,
		'component'         => $activity->component,
		'type'              => $activity->type,
	);

	if ( ! class_exists( 'Youzify' ) ) {
		get_template_part( 'template-parts/content', 'user-preview', $args );
	}
}

function reign_new_group_avatar_activity_content( $activity ) {
	$args = array(
		'activity_id'       => $activity->id,
		'user_id'           => $activity->user_id,
		'item_id'           => $activity->item_id,
		'secondary_item_id' => $activity->secondary_item_id,
		'component'         => $activity->component,
		'type'              => $activity->type,
	);

	if ( ! class_exists( 'Youzify' ) ) {
		get_template_part( 'template-parts/content', 'user-preview', $args );
	}
}


function reign_register_activity_actions() {
	global $wbtm_reign_settings;

	if ( isset( $wbtm_reign_settings['reign_buddyextender']['member_cover_image'] ) ) {
		bp_activity_set_action(
			buddypress()->members->id,
			'new_cover_photo',
			__( 'Member changed cover photo', 'reign' ),
			'bp_members_format_activity_action_new_cover_photo',
			__( 'Updated Cover Photo', 'reign' )
		);

	}

	if ( bp_is_active( 'groups' ) ) {
		/* Gropup Photo */

		if ( isset( $wbtm_reign_settings['reign_buddyextender']['group_image'] ) ) {
			bp_activity_set_action(
				buddypress()->groups->id,
				'new_group_avatar',
				__( 'Member changed group picture', 'reign' ),
				'bp_groups_format_activity_action_new_group_avatar',
				__( 'Updated Group Photos', 'reign' )
			);
		}

		/* Gropup Cover Photo */
		if ( isset( $wbtm_reign_settings['reign_buddyextender']['group_cover_image'] ) ) {
			bp_activity_set_action(
				buddypress()->groups->id,
				'new_group_cover_photo',
				__( 'Member changed group cover photo', 'reign' ),
				'bp_groups_format_activity_action_new_group_cover_photo',
				__( 'Updated Group Cover Photos', 'reign' )
			);
		}
	}

}
add_action( 'bp_register_activity_actions', 'reign_register_activity_actions' );


/**
 * Format 'new_cover_photo' activity actions.
 *
 * @since 5.8.4
 *
 * @param string $action   Static activity action.
 * @param object $activity Activity object.
 * @return string
 */
function bp_members_format_activity_action_new_cover_photo( $action, $activity ) {
	$userlink = bp_core_get_userlink( $activity->user_id );

	/* translators: %s: user link */
	$action = sprintf( esc_html__( '%s changed their cover photo', 'reign' ), $userlink );

	// Legacy filter - pass $user_id instead of $activity.
	if ( has_filter( 'bp_xprofile_new_avatar_action' ) ) {
		$action = apply_filters( 'bp_xprofile_new_avatar_action', $action, $activity->user_id );
	}

	return apply_filters( 'bp_members_format_activity_action_new_cover_photo', $action, $activity );
}


/**
 * Format 'new_group_avatar' activity actions.
 *
 * @since 5.8.4
 *
 * @param string $action   Static activity action.
 * @param object $activity Activity object.
 * @return string
 */


function bp_groups_format_activity_action_new_group_avatar( $action, $activity ) {
	$userlink = bp_core_get_userlink( $activity->user_id );

	$group      = groups_get_group( array( 'group_id' => $activity->item_id ) );
	$group_link = bp_get_group_permalink( $group );
	$grouplink  = '<a href="' . esc_url( $group_link ) . '">' . $group->name . '</a>';

	/* translators: %s: user link */
	$action = sprintf( esc_html__( '%1$s changed %2$s group photo', 'reign' ), $userlink, $grouplink );

	return apply_filters( 'bp_groups_format_activity_action_new_group_avatar', $action, $activity );
}


/**
 * Format 'new_group_cover_photo' activity actions.
 *
 * @since 5.8.4
 *
 * @param string $action   Static activity action.
 * @param object $activity Activity object.
 * @return string
 */


function bp_groups_format_activity_action_new_group_cover_photo( $action, $activity ) {
	$userlink = bp_core_get_userlink( $activity->user_id );

	$group      = groups_get_group( array( 'group_id' => $activity->item_id ) );
	$group_link = bp_get_group_permalink( $group );
	$grouplink  = '<a href="' . esc_url( $group_link ) . '">' . $group->name . '</a>';

	/* translators: %s: user link */
	$action = sprintf( esc_html__( '%1$s changed %2$s group cover photo', 'reign' ), $userlink, $grouplink );

	return apply_filters( 'bp_groups_format_activity_action_new_group_cover_photo', $action, $activity );
}



/**
 * Adds an activity stream item when a user has uploaded a new cover image.
 *
 * @since 5.8.4
 *
 * @param int $user_id The user id the avatar was set for.
 */
function reign_members_cover_image_uploaded( $item_id, $name, $cover_url, $feedback_code ) {
	// Bail if activity component is not active.
	global $wbtm_reign_settings;

	if ( ! isset( $wbtm_reign_settings['reign_buddyextender']['member_cover_image'] ) ) {
		return false;
	}

	if ( ! bp_is_active( 'activity' ) ) {
		return false;
	}

	if ( empty( $user_id ) ) {
		$user_id = bp_displayed_user_id();
	}

	// Add the activity.
	$activity_id = bp_activity_add(
		array(
			'user_id'           => $user_id,
			'component'         => buddypress()->members->id,
			'type'              => 'new_cover_photo',
			'item_id'           => $item_id,
			'secondary_item_id' => $item_id,
		)
	);

	$type                = pathinfo( $cover_url, PATHINFO_EXTENSION );
	$data                = wp_remote_get( $cover_url );
	$data                = wp_remote_retrieve_body( $data );
	$avatar_image_base64 = 'data:image/' . $type . ';base64,' . base64_encode( $data );
	bp_activity_update_meta( $activity_id, 'cover_image', $avatar_image_base64 );
	bp_activity_update_meta( $activity_id, 'cover_image_name', $name );

	/*
	 Upload Profile Cover Image into WP Media Library */
	/*
	$title = basename( $cover_url );
	require_once ABSPATH . 'wp-admin/includes/image.php';
	require_once ABSPATH . 'wp-admin/includes/file.php';
	require_once ABSPATH . 'wp-admin/includes/media.php';
	$cover_image_url = media_sideload_image( $cover_url, 0, $title, 'src' );

	bp_activity_update_meta( $activity_id, 'cover_image', $cover_image_url );
	bp_activity_update_meta( $activity_id, 'cover_image_name', $name );
	*/
}
if ( function_exists( 'buddypress' ) && ! isset( buddypress()->buddyboss ) ) {
	add_action( 'members_cover_image_uploaded', 'reign_members_cover_image_uploaded', 10, 4 );
}

if ( function_exists( 'buddypress' ) && isset( buddypress()->buddyboss ) ) {
	add_action( 'xprofile_cover_image_uploaded', 'reign_members_cover_image_uploaded', 10, 4 );
}


/**
 * Adds an activity stream item when a user has uploaded a new group cover image.
 *
 * @since 5.8.4
 */
function reign_groups_cover_image_uploaded( $item_id, $name, $cover_url, $feedback_code ) {
	// Bail if activity component is not active.

	global $wbtm_reign_settings;

	if ( ! isset( $wbtm_reign_settings['reign_buddyextender']['group_cover_image'] ) ) {
		return false;
	}

	if ( ! bp_is_active( 'activity' ) ) {
		return false;
	}

	if ( empty( $user_id ) ) {
		$user_id = bp_displayed_user_id();
	}

	$user_id = get_current_user_id();

	// Add the activity.
	$activity_id = bp_activity_add(
		array(
			'user_id'   => $user_id,
			'component' => buddypress()->groups->id,
			'type'      => 'new_group_cover_photo',
			'item_id'   => $item_id,
		)
	);

	$type                = pathinfo( $cover_url, PATHINFO_EXTENSION );
	$data                = wp_remote_get( $cover_url );
	$data                = wp_remote_retrieve_body( $data );
	$avatar_image_base64 = 'data:image/' . $type . ';base64,' . base64_encode( $data );
	bp_activity_update_meta( $activity_id, 'group_cover_image', $avatar_image_base64 );
	bp_activity_update_meta( $activity_id, 'group_cover_image_name', $name );

	/*
	 Upload Profile Cover Image into WP Media Library */
	/*
	$title = basename( $cover_url );
	require_once ABSPATH . 'wp-admin/includes/image.php';
	require_once ABSPATH . 'wp-admin/includes/file.php';
	require_once ABSPATH . 'wp-admin/includes/media.php';
	$cover_image_url = media_sideload_image( $cover_url, 0, $title, 'src' );

	bp_activity_update_meta( $activity_id, 'group_cover_image', $cover_image_url );
	bp_activity_update_meta( $activity_id, 'group_cover_image_name', $name );
	*/
}
add_action( 'groups_cover_image_uploaded', 'reign_groups_cover_image_uploaded', 10, 4 );

/**
 * Adds an activity stream item when a user has uploaded a new group avatar.
 *
 * @since 5.8.4
 */
function reign_groups_avatar_uploaded( $item_id, $type ) {

	global $wbtm_reign_settings;

	if ( ! isset( $wbtm_reign_settings['reign_buddyextender']['group_image'] ) ) {
		return false;
	}
	// Bail if activity component is not active.
	if ( ! bp_is_active( 'activity' ) ) {
		return false;
	}

	$user_id = get_current_user_id();

	// Add the activity.
	$activity_id = bp_activity_add(
		array(
			'user_id'   => $user_id,
			'component' => buddypress()->groups->id,
			'type'      => 'new_group_avatar',
			'item_id'   => $item_id,
		)
	);

	$avatar_url          = bp_core_fetch_avatar(
		array(
			'item_id'    => $item_id,
			'type'       => 'full',
			'avatar_dir' => 'group-avatars',
			'object'     => 'group',
			'width'      => 400,
			'height'     => 400,
			'html'       => false,
		)
	);
	$title               = basename( $avatar_url );
	$type                = pathinfo( $avatar_url, PATHINFO_EXTENSION );
	$data                = wp_remote_get( $avatar_url );
	$data                = wp_remote_retrieve_body( $data );
	$avatar_image_base64 = 'data:image/' . $type . ';base64,' . base64_encode( $data );
	bp_activity_update_meta( $activity_id, 'group_avatar_image', $avatar_image_base64 );
	bp_activity_update_meta( $activity_id, 'group_avatar_image_name', $title );

	/*
	 Upload Profile Cover Image into WP Media Library */
	/*
	$title = basename( $avatar_url );
	require_once ABSPATH . 'wp-admin/includes/image.php';
	require_once ABSPATH . 'wp-admin/includes/file.php';
	require_once ABSPATH . 'wp-admin/includes/media.php';
	$avatar_image_url = media_sideload_image( $avatar_url, 0, $title, 'src' );

	bp_activity_update_meta( $activity_id, 'group_avatar_image', $avatar_image_url );
	bp_activity_update_meta( $activity_id, 'group_avatar_image_name', $title );
	*/
}
add_action( 'groups_avatar_uploaded', 'reign_groups_avatar_uploaded', 20, 2 );



add_filter( 'bp_get_activity_action_pre_meta', 'reign_group_activity_secondary_avatars', 20, 2 );
function reign_group_activity_secondary_avatars( $action, $activity ) {

	if ( $activity->type == 'new_group_avatar' || $activity->type == 'new_group_cover_photo' ) {
		switch ( $activity->component ) {
			case 'groups':
				global $activities_template;
				$action = $activities_template->activity->action;
				break;
		}
	}
	return $action;
}

function reign_bp_avatar_activity_add( $args, $activity_id ) {

	if ( $args['type'] == 'new_avatar' && ( $args['component'] == 'members' || $args['component'] == 'profile' ) ) {
		$avatar_url          = bp_core_fetch_avatar(
			array(
				'item_id' => $args['user_id'],
				'type'    => 'full',
				'width'   => 400,
				'height'  => 400,
				'html'    => false,
			)
		);
		$title               = basename( $avatar_url );
		$type                = pathinfo( $avatar_url, PATHINFO_EXTENSION );
		$data                = wp_remote_get( $avatar_url );
				$data        = wp_remote_retrieve_body( $data );
		$avatar_image_base64 = 'data:image/' . $type . ';base64,' . base64_encode( $data );
		bp_activity_update_meta( $activity_id, 'member_avatar_image', $avatar_image_base64 );
		bp_activity_update_meta( $activity_id, 'member_avatar_image_name', $title );

		/*
		 Upload Profile Cover Image into WP Media Library */
		/*
		require_once ABSPATH . 'wp-admin/includes/image.php';
		require_once ABSPATH . 'wp-admin/includes/file.php';
		require_once ABSPATH . 'wp-admin/includes/media.php';
		$avatar_image_url = media_sideload_image( $avatar_url, 0, $title, 'src' );

		bp_activity_update_meta( $activity_id, 'member_avatar_image', $avatar_image_url );
		bp_activity_update_meta( $activity_id, 'member_avatar_image_name', $title );
		*/
	}
}

if ( function_exists( 'buddypress' ) && version_compare( buddypress()->version, '10.0.0', '<' ) && ! isset( buddypress()->buddyboss ) ) {
	add_action( 'bp_activity_add', 'reign_bp_avatar_activity_add', 20, 2 );
}

/**
 * Function will add feature image for blog post in the activity feed content.
 *
 * @param string $content
 * @param int    $blog_post_id
 *
 * @return string $content
 *
 * @since 3.4.0
 */
function reign_add_feature_image_blog_post_as_activity_content_callback( $content, $blog_post_id ) {
	if ( function_exists( 'buddypress' ) && ! isset( buddypress()->buddyboss ) ) {
		if ( ! empty( $blog_post_id ) && ! empty( get_post_thumbnail_id( $blog_post_id ) ) ) {
			$content .= sprintf( ' <a class="reign-post-img-link" href="%s"><img src="%s" /></a>', esc_url( get_permalink( $blog_post_id ) ), esc_url( wp_get_attachment_image_url( get_post_thumbnail_id( $blog_post_id ), 'full' ) ) );
		}
	}

	return $content;
}

add_filter( 'reign_add_feature_image_blog_post_as_activity_content', 'reign_add_feature_image_blog_post_as_activity_content_callback', 10, 2 );

add_action( 'bp_before_activity_activity_content', 'reign_bp_blogs_activity_content_set_temp_content' );

/**
 * Function which set the temporary content on the blog post activity.
 *
 * @since 3.4.0
 */
function reign_bp_blogs_activity_content_set_temp_content() {

	if ( function_exists( 'buddypress' ) && ! isset( buddypress()->buddyboss ) ) {

		global $activities_template;

		$activity = $activities_template->activity;
		if ( ( 'blogs' === $activity->component ) && isset( $activity->secondary_item_id ) && 'new_blog_' . get_post_type( $activity->secondary_item_id ) === $activity->type ) {
			$content = get_post( $activity->secondary_item_id );
			// If we converted $content to an object earlier, flip it back to a string.
			if ( is_a( $content, 'WP_Post' ) ) {
				$activities_template->activity->content = '&#8203;';
			}
		} elseif ( 'blogs' === $activity->component && 'new_blog_comment' === $activity->type && $activity->secondary_item_id && $activity->secondary_item_id > 0 ) {
			$activities_template->activity->content = '&#8203;';
		}
	}
}

add_filter( 'bp_get_activity_content_body', 'reign_bp_blogs_activity_content_with_read_more', 9999, 2 );

/**
 * Function which set the content on activity blog post.
 *
 * @param $content
 * @param $activity
 *
 * @return string
 *
 * @since 3.4.0
 */
function reign_bp_blogs_activity_content_with_read_more( $content, $activity ) {

	if ( function_exists( 'buddypress' ) && ! isset( buddypress()->buddyboss ) ) {

		if ( ( 'blogs' === $activity->component ) && isset( $activity->secondary_item_id ) && 'new_blog_' . get_post_type( $activity->secondary_item_id ) === $activity->type ) {
			$blog_post = get_post( $activity->secondary_item_id );
			// If we converted $content to an object earlier, flip it back to a string.
			if ( is_a( $blog_post, 'WP_Post' ) ) {
				$content_img = apply_filters( 'reign_add_feature_image_blog_post_as_activity_content', '', $blog_post->ID );
				$post_title  = sprintf( '<a class="reign-post-title-link" href="%s"><span class="reign-post-title">%s</span></a>', esc_url( get_permalink( $blog_post->ID ) ), esc_html( $blog_post->post_title ) );
				$content     = bp_create_excerpt( bp_strip_script_and_style_tags( html_entity_decode( get_the_excerpt( $blog_post->ID ) ) ) );
				if ( false !== strrpos( $content, __( '&hellip;', 'reign' ) ) ) {
					$content = str_replace( ' [&hellip;]', '&hellip;', $content );
					$content = apply_filters_ref_array( 'bp_get_activity_content', array( $content, $activity ) );
					preg_match( '/<iframe.*src=\"(.*)\".*><\/iframe>/isU', $content, $matches );
					if ( isset( $matches ) && array_key_exists( 0, $matches ) && ! empty( $matches[0] ) ) {
						$iframe  = $matches[0];
						$content = strip_tags( preg_replace( '/<iframe.*?\/iframe>/i', '', $content ), '<a>' );

						$content .= $iframe;
					}
					$content = sprintf( '%1$s <div class="reign-content-wrp">%2$s %3$s</div>', $content_img, $post_title, wpautop( $content ) );
				} else {
					$content = apply_filters_ref_array( 'bp_get_activity_content', array( $content, $activity ) );
					$content = strip_tags( $content, '<a><iframe><img><span><div>' );
					preg_match( '/<iframe.*src=\"(.*)\".*><\/iframe>/isU', $content, $matches );
					if ( isset( $matches ) && array_key_exists( 0, $matches ) && ! empty( $matches[0] ) ) {
						$content = $content;
					}
					$content = sprintf( '%1$s <div class="reign-content-wrp">%2$s %3$s</div>', $content_img, $post_title, wpautop( $content ) );
				}
			}
		} elseif ( 'blogs' === $activity->component && 'new_blog_comment' === $activity->type && $activity->secondary_item_id && $activity->secondary_item_id > 0 ) {
			$comment = get_comment( $activity->secondary_item_id );
			$content = bp_create_excerpt( html_entity_decode( $comment->comment_content ) );
			if ( false !== strrpos( $content, __( '&hellip;', 'reign' ) ) ) {
				$content     = str_replace( ' [&hellip;]', '&hellip;', $content );
				$append_text = apply_filters( 'bp_activity_excerpt_append_text', __( ' Read more', 'reign' ) );
				$content     = wpautop( sprintf( '%1$s<span class="activity-blog-post-link"><a href="%2$s" rel="nofollow">%3$s</a></span>', $content, get_comment_link( $activity->secondary_item_id ), $append_text ) );
			}
		}
	}

	return $content;
}

/**
 * Added buddypress activity types activity embed css.
 *
 * @param $content
 * @param $activity
 *
 * @return string
 *
 * @since 6.0.0
 */
function reign_activity_embed_add_inline_styles() {
	?>
	<style type="text/css">
			.reign-user-preview {
				position: relative;
				margin-top: 28px;
				margin-bottom: 15px;
			}

			.reign-user-preview .reign-user-preview-cover img {
				width: 100%;
				height: 132px;
				object-fit: cover;
			}

			.reign-preview-widget .user-short-description {
				padding-top: 44px;
			}

			.reign-short-description {
				position: relative;
				padding-top: 62px;
			}

			.reign-user-avatar-content {
				margin-top: -75px;
				margin-bottom: 15px;
			}

			.reign-user-short-description {
				text-align: center;
			}

			.reign-user-avatar-content img {
				background: rgba(218, 218, 218, 0.5);
				padding: 5px;
			}

			@media(min-width: 544px) {
				.reign-user-stats {
					position: absolute;
					left: 0;
					bottom: 0;
				}
			}

			@media(max-width: 543px) {
				.reign-user-stats {
					text-align: center;
					margin-top: 10px;
				}
			}

			.bp-nouveau .activity-list .activity-item .activity-content .activity-inner .reign-user-stats .reign-user-stat-title,
			.bp-nouveau .activity-list .activity-item .activity-content .activity-inner .reign-user-stats .reign-user-stat-text {
				font-size: 12px;
				line-height: normal;
			}

			.bp-nouveau .activity-list .activity-item .activity-content .activity-inner .reign-user-stats .reign-user-stat-text {
				text-transform: uppercase;
				margin-top: 5px;
			}

			#buddypress .activity-content .activity-inner .reign-user-short-description a {
				color: inherit;
				background: transparent;
				font-size: inherit;
			}

			@media(min-width: 544px) {
				.bp-profile-button {
					text-align: right;
					margin-top: -24px;
				}
				.bp-profile-button a {
					padding: 0 !important;
				}
			}
	</style>
	<?php
}

add_action( 'embed_head', 'reign_activity_embed_add_inline_styles', 20 );

function bp_nouveau_reign_signup_terms_privacy() {
	$page_ids             = bp_core_get_directory_page_ids();
	$show_legal_agreement = bb_register_legal_agreement();

	$terms   = isset( $page_ids['terms'] ) ? $page_ids['terms'] : false;
	$privacy = isset( $page_ids['privacy'] ) ? $page_ids['privacy'] : (int) get_option( 'wp_page_for_privacy_policy' );

	// Do not show the page if page is not published.
	if ( false !== $terms && 'publish' !== get_post_status( $terms ) ) {
		$terms = false;
	}

	// Do not show the page if page is not published.
	if ( false !== $privacy && 'publish' !== get_post_status( $privacy ) ) {
		$privacy = false;
	}

	if ( ! $terms && ! $privacy ) {
		return false;
	}

	if ( ! empty( $terms ) && ! empty( $privacy ) ) {
		$terms_link   = '<a class="popup-modal-register popup-terms" href="' . esc_url( get_permalink( $terms ) ) . '" target="_blank">' . get_the_title( $terms ) . '</a>';
		$privacy_link = '<a class="popup-modal-register popup-privacy" href="' . esc_url( get_permalink( $privacy ) ) . '" target="_blank">' . get_the_title( $privacy ) . '</a>';
		?>
		<?php if ( $show_legal_agreement ) { ?>
			<div class="input-options checkbox-options">
				<div class="bp-checkbox-wrap">
					<input type="checkbox" name="legal_agreement" id="legal_agreement" value="1" class="bs-styled-checkbox">
					<label for="legal_agreement" class="option-label"><?php printf( __( 'I agree to the %1$s and %2$s.', 'reign' ), $terms_link, $privacy_link ); ?></label>
				</div>
			</div>
		<?php } else { ?>
			<p class="register-privacy-info">
				<?php printf( __( 'By creating an account you are agreeing to the %1$s and %2$s.', 'reign' ), $terms_link, $privacy_link ); ?>
			</p>
			<?php
		}
	} elseif ( empty( $terms ) && ! empty( $privacy ) ) {
		$privacy_link = '<a class="popup-modal-register popup-privacy" href="' . esc_url( get_permalink( $privacy ) ) . '" target="_blank">' . get_the_title( $privacy ) . '</a>';
		?>
		<?php if ( $show_legal_agreement ) { ?>
			<div class="input-options checkbox-options">
				<div class="bp-checkbox-wrap">
					<input type="checkbox" name="legal_agreement" id="legal_agreement" value="1" class="bs-styled-checkbox">
					<label for="legal_agreement" class="option-label"><?php printf( __( 'I agree to the %s.', 'reign' ), $privacy_link ); ?></label>
				</div>
			</div>
		<?php } else { ?>
			<p class="register-privacy-info">
				<?php printf( __( 'By creating an account you are agreeing to the %s.', 'reign' ), $privacy_link ); ?>
			</p>
			<?php
		}
	} elseif ( ! empty( $terms ) && empty( $privacy ) ) {
		$terms_link = '<a class="popup-modal-register popup-terms" href="' . esc_url( get_permalink( $terms ) ) . '" target="_blank">' . get_the_title( $terms ) . '</a>';
		?>
		<?php if ( $show_legal_agreement ) { ?>
			<div class="input-options checkbox-options">
				<div class="bp-checkbox-wrap">
					<input type="checkbox" name="legal_agreement" id="legal_agreement" value="1" class="bs-styled-checkbox">
					<label for="legal_agreement" class="option-label"><?php printf( __( 'I agree to the %s.', 'reign' ), $terms_link ); ?></label>
				</div>
			</div>
		<?php } else { ?>
			<p class="register-privacy-info">
				<?php printf( __( 'By creating an account you are agreeing to the %s.', 'reign' ), $terms_link ); ?>
			</p>
			<?php
		}
	}

	if ( $show_legal_agreement ) {
		do_action( 'bp_legal_agreement_errors' );
	}
}

if ( ! function_exists( 'reign_notifications_avatar' ) ) {

	/**
	 * Added buddypress notification avatar
	 *
	 * @since 6.3.6
	 */
	function reign_notifications_avatar() {
		$bp      = buddypress();
		$user_id = $bp->notifications->query_loop->notification->secondary_item_id;
		if ( empty( $user_id ) ) {
			$user_id = $bp->notifications->query_loop->notification->item_id;
		}
		echo bp_core_fetch_avatar( /* phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped */
			array(
				'item_id' => $user_id,
				'type'    => 'thumb',
			)
		);
	}
}


add_filter( 'bp_nouveau_get_activity_entry_buttons', 'reign_theme_bp_nouveau_get_activity_entry_buttons', 99, 2 );
function reign_theme_bp_nouveau_get_activity_entry_buttons( $buttons, $activity_id ) {
	if ( function_exists( 'buddypress' ) && ! isset( buddypress()->buddyboss ) ) {		
		unset( $buttons['activity_delete'] );
	}	
	
	return $buttons;
}

/*
 * Replace Mark as Favirite to Like and Rrmove Favirite to Unlike
 */

add_filter('gettext', 'reign_bp_string_translate', 10, 3);
function reign_bp_string_translate( $translation, $text, $domain) {
	
	if ( $domain == 'buddypress' ) {
		if ( $text == 'Remove Favorite' ) {
			$translation = esc_html__( 'Unlike', 'reign-theme');
		}
		
		if ( $text == 'Mark as Favorite' ) {
			$translation = esc_html__( 'Like', 'reign-theme');
		}
		
		if ( $text == 'My Favorites' ) {
			$translation = esc_html__( 'Likes', 'reign-theme');
		}
	}
	
	return $translation;
}


function bp_nouveau_activity_entry_dropdown_toggle_buttons( $args = array() ) {
	$output = join( ' ', bb_nouveau_get_activity_entry_dropdown_toggle_buttons( $args ) );

	ob_start();

	do_action( 'bp_activity_entry_dropdown_toggle_meta' );

	$output .= ob_get_clean();

	$has_content = trim( $output, ' ' );
	if ( ! $has_content ) {
		return;
	}

	if ( ! $args ) {
		$args = array( 'container_classes' => array( 'bp-activity-more-options-wrap', 'activity-meta' ) );
	}

	$output = sprintf( '<span class="bp-activity-more-options-action activity-meta action" data-balloon-pos="up" data-balloon="%s"><i class="fa fa-ellipsis-h"></i></span><div class="bp-activity-more-options">%s</div>', esc_html__( 'More Options', 'reign' ), $output );

	bp_nouveau_wrapper( array_merge( $args, array( 'output' => $output ) ) );
}

function bb_nouveau_get_activity_entry_dropdown_toggle_buttons( $args ) {
	 $buttons = array();
	if ( ! isset( $GLOBALS['activities_template'] ) ) {
		return $buttons;
	}

	$activity_id    = bp_get_activity_id();
	$activity_type  = bp_get_activity_type();
	$parent_element = '';
	$button_element = 'a';

	if ( ! $activity_id ) {
		return $buttons;
	}

	/*
	 * If the container is set to 'ul' force the $parent_element to 'li',
	 * else use parent_element args if set.
	 *
	 * This will render li elements around anchors/buttons.
	 */
	if ( isset( $args['container'] ) && 'ul' === $args['container'] ) {
		$parent_element = 'li';
	} elseif ( ! empty( $args['parent_element'] ) ) {
		$parent_element = $args['parent_element'];
	}

	$parent_attr = ( ! empty( $args['parent_attr'] ) ) ? $args['parent_attr'] : array();

	/*
	 * If we have an arg value for $button_element passed through
	 * use it to default all the $buttons['button_element'] values
	 * otherwise default to 'a' (anchor)
	 * Or override & hardcode the 'element' string on $buttons array.
	 *
	 */
	if ( ! empty( $args['button_element'] ) ) {
		$button_element = $args['button_element'];
	}

	// The delete button is always created, and removed later on if needed.
	$delete_args = array();

	/*
	 * As the delete link is filterable we need this workaround
	 * to try to intercept the edits the filter made and build
	 * a button out of it.
	 */
	if ( has_filter( 'bp_get_activity_delete_link' ) ) {
		preg_match( '/<a\s[^>]*>(.*)<\/a>/siU', bp_get_activity_delete_link(), $link );

		if ( ! empty( $link[0] ) && ! empty( $link[1] ) ) {
			$delete_args['link_text'] = $link[1];
			$subject                  = str_replace( $delete_args['link_text'], '', $link[0] );
		}

		preg_match_all( '/([\w\-]+)=([^"\'> ]+|([\'"]?)(?:[^\3]|\3+)+?\3)/', $subject, $attrs );

		if ( ! empty( $attrs[1] ) && ! empty( $attrs[2] ) ) {
			foreach ( $attrs[1] as $key_attr => $key_value ) {
				$delete_args[ 'link_' . $key_value ] = trim( $attrs[2][ $key_attr ], '"' );
			}
		}

		$delete_args = bp_parse_args(
			$delete_args,
			array(
				'link_text'   => '',
				'button_attr' => array(
					'link_id'         => '',
					'link_href'       => '',
					'link_class'      => '',
					'link_rel'        => 'nofollow',
					'data_bp_tooltip' => '',
				),
			),
			'nouveau_get_activity_entry_buttons'
		);
	}

	if ( empty( $delete_args['link_href'] ) ) {
		$delete_args = array(
			'button_element'  => $button_element,
			'link_id'         => '',
			'link_class'      => 'button item-button bp-secondary-action bp-tooltip delete-activity confirm',
			'link_rel'        => 'nofollow',
			'data_bp_tooltip' => _x( 'Delete', 'button', 'buddypress' ),
			'link_text'       => _x( 'Delete', 'button', 'buddypress' ),
			'link_href'       => bp_get_activity_delete_url(),
		);

		// If button element set add nonce link to data-attr attr
		if ( 'button' === $button_element ) {
			$delete_args['data-attr'] = bp_get_activity_delete_url();
			$delete_args['link_href'] = '';
		} else {
			$delete_args['link_href'] = bp_get_activity_delete_url();
			$delete_args['data-attr'] = '';
		}
	}

	$buttons['activity_delete'] = array(
		'id'                => 'activity_delete',
		'position'          => 35,
		'component'         => 'activity',
		'parent_element'    => $parent_element,
		'parent_attr'       => $parent_attr,
		'must_be_logged_in' => true,
		'button_element'    => $button_element,
		'button_attr'       => array(
			'id'              => $delete_args['link_id'],
			'href'            => $delete_args['link_href'],
			'class'           => $delete_args['link_class'],
			'data-bp-tooltip' => $delete_args['data_bp_tooltip'],
			'data-bp-nonce'   => $delete_args['data-attr'],
		),
		'link_text'         => sprintf( '<span class="bp-screen-reader-text">%s</span>', esc_html( $delete_args['data_bp_tooltip'] ) ),
	);

	// Add the Spam Button if supported
	if ( bp_is_akismet_active() && isset( buddypress()->activity->akismet ) && bp_activity_user_can_mark_spam() ) {
		$buttons['activity_spam'] = array(
			'id'                => 'activity_spam',
			'position'          => 45,
			'component'         => 'activity',
			'parent_element'    => $parent_element,
			'parent_attr'       => $parent_attr,
			'must_be_logged_in' => true,
			'button_element'    => $button_element,
			'button_attr'       => array(
				'class'           => 'bp-secondary-action spam-activity confirm button item-button bp-tooltip',
				'id'              => 'activity_make_spam_' . $activity_id,
				'data-bp-tooltip' => _x( 'Spam', 'button', 'buddypress' ),
			),
			'link_text'         => sprintf(
				/** @todo: use a specific css rule for this */
				'<span class="dashicons dashicons-flag" style="color:#a00;vertical-align:baseline;width:18px;height:18px" aria-hidden="true"></span><span class="bp-screen-reader-text">%s</span>',
				esc_html_x( 'Spam', 'button', 'buddypress' )
			),
		);

		// If button element, add nonce link to data attribute.
		if ( 'button' === $button_element ) {
			$data_element = 'data-bp-nonce';
		} else {
			$data_element = 'href';
		}

		$buttons['activity_spam']['button_attr'][ $data_element ] = wp_nonce_url(
			bp_get_root_domain() . '/' . bp_nouveau_get_component_slug( 'activity' ) . '/spam/' . $activity_id . '/',
			'bp_activity_akismet_spam_' . $activity_id
		);
	}
	/**
	 * Filter to add your buttons, use the position argument to choose where to insert it.
	 *
	 * @since BuddyBoss 1.7.2
	 *
	 * @param array $buttons     The list of buttons.
	 * @param int   $activity_id The current activity ID.
	 */
	$buttons_group = apply_filters( 'bb_nouveau_get_activity_entry_dropdown_toggle_buttons', $buttons, $activity_id );

	if ( ! $buttons_group ) {
		return $buttons;
	}

	// It's the first entry of the loop, so build the Group and sort it.
	if ( ! isset( bp_nouveau()->activity->entry_buttons ) || ! is_a( bp_nouveau()->activity->entry_buttons, 'BP_Buttons_Reign_Group' ) ) {
		$sort                                 = true;
		bp_nouveau()->activity->entry_buttons = new BP_Buttons_Reign_Group( $buttons_group );

		// It's not the first entry, the order is set, we simply need to update the Buttons Group.
	} else {
		$sort = false;
		bp_nouveau()->activity->entry_buttons->update( $buttons_group );
	}

	$return = bp_nouveau()->activity->entry_buttons->get( $sort );

	if ( ! $return ) {
		return array();
	}

	// Remove the Delete button if the user can't delete.
	if ( ! bp_activity_user_can_delete() ) {
		unset( $return['activity_delete'] );
	}

	do_action_ref_array( 'bb_nouveau_return_activity_entry_dropdown_toggle_buttons', array( &$return, $activity_id ) );

	return $return;
}

class BP_Buttons_Reign_Group {

	protected $group = array();

	public function __construct( $args = array() ) {
		foreach ( $args as $arg ) {
			$this->add( $arg );
		}
	}

	public function sort( $buttons ) {
		$sorted = array();

		foreach ( $buttons as $button ) {
			$position = 99;

			if ( isset( $button['position'] ) ) {
				$position = (int) $button['position'];
			}

			// If position is already taken, move to the first next available
			if ( isset( $sorted[ $position ] ) ) {
				$sorted_keys = array_keys( $sorted );

				do {
					$position += 1;
				} while ( in_array( $position, $sorted_keys, true ) );
			}

			$sorted[ $position ] = $button;
		}

		ksort( $sorted );
		return $sorted;
	}


	public function get( $sort = true ) {
		$buttons = array();

		if ( empty( $this->group ) ) {
			return $buttons;
		}

		if ( true === $sort ) {
			$this->group = $this->sort( $this->group );
		}

		foreach ( $this->group as $key_button => $button ) {
			// Reindex with ids.
			if ( true === $sort ) {
				$this->group[ $button['id'] ] = $button;
				unset( $this->group[ $key_button ] );
			}

			$buttons[ $button['id'] ] = bp_get_button( $button );
		}

		return $buttons;
	}


	public function update( $args = array() ) {
		$this->group = array();
		foreach ( $args as $id => $params ) {
			$this->set( $params );
		}
	}


	private function add( $args ) {
		$r = bp_parse_args(
			(array) $args,
			array(
				'id'                => '',
				'position'          => 99,
				'component'         => '',
				'must_be_logged_in' => true,
				'block_self'        => false,
				'parent_element'    => false,
				'parent_attr'       => array(),
				'button_element'    => 'a',
				'button_attr'       => array(),
				'link_text'         => '',
			),
			'buttons_group_constructor'
		);

		// Just don't set the button if a param is missing
		if ( empty( $r['id'] ) || empty( $r['component'] ) || empty( $r['link_text'] ) ) {
			return false;
		}

		$r['id'] = sanitize_key( $r['id'] );

		// If the button already exist don't add it
		if ( isset( $this->group[ $r['id'] ] ) ) {
			return false;
		}

		/*
		 * If, in bp_nouveau_get_*_buttons(), we pass through a false value for 'parent_element'
		 * but we have attributtes for it in the array, let's default to setting a div.
		 *
		 * Otherwise, the original false value will be passed through to BP buttons.
		 * @todo: this needs review, probably trying to be too clever
		 */
		if ( ( ! empty( $r['parent_attr'] ) ) && false === $r['parent_element'] ) {
			$r['parent_element'] = 'div';
		}

		$this->group[ $r['id'] ] = $r;
		return true;
	}
}




function bp_activity_get_share_count( $post_id, $is_bp = false ) {
	$share_count = 0;

	if ( empty( $post_id ) ) {
		return $share_count;
	}

	if ( ( function_exists( 'bp_is_activity_directory' ) && bp_is_activity_directory() ) || $is_bp == true  ) {
		$share_count = bp_activity_get_meta( $post_id, 'share_count', true );
	} elseif ( is_single() ) {
		$share_count = bp_activity_get_meta( $post_id, 'share_count', true );
	}

	if ( empty( $share_count ) ) {
		$share_count = 0;
	}

	return $share_count;
}



function bp_activity_get_post_comment_count( $post_id ) {
	$comment_count = get_comments_number( $post_id );
	if ( empty( $comment_count ) ) {
		$comment_count = 0;
	}
	return $comment_count;
}




if ( ! function_exists( 'reign_theme_set_unread_notification' ) ) {

	/**
	 * Added new function to unread notification from header
	 *
	 * @since 6.6.0
	 */
	function reign_theme_set_unread_notification() {

		if ( ! function_exists( 'buddypress' ) && ! bp_is_active( 'notifications' ) ) {
			return;
		}

		$notif_id = filter_input( INPUT_POST, 'notification_id', FILTER_SANITIZE_STRING );
		if ( 'all' !== $notif_id  ) {
			$notif_id = filter_input( INPUT_POST, 'notification_id', FILTER_SANITIZE_NUMBER_INT );
		}
		if( ! empty( $notif_id ) && $notif_id !== 'all' ) {
			BP_Notifications_Notification::update(
				array( 'is_new' => 0 ),
				array( 'id' => $notif_id )
			);
		} else if ( $notif_id === 'all' ) {
			$user_id 			= bp_loggedin_user_id();
			$notification_ids 	= BP_Notifications_Notification::get(
				array(
					'user_id' 			=> $user_id,
					'order_by'			=> 'date_notified',
					'sort_order'		=> 'DESC',
					'page'      		=> 1,
					'per_page'      	=> 10,
					'update_meta_cache' => false
				)
			);
			if( $notification_ids ) {
				foreach ( $notification_ids as $notification_id ) {
					BP_Notifications_Notification::update(
						array( 'is_new' => 0 ),
						array( 'id' => $notification_id->id )
					);
				}
			}
		}
		$response = array();
		ob_start();		
		
			if ( bp_has_notifications(
				array(
					'user_id'  => bp_loggedin_user_id(),
					'per_page' => 10,
					'max'      => 10,
					'is_new'   => 1,
				)
			) ) :				
				while ( bp_the_notifications() ) :
					bp_the_notification();
					?>
					<div class="dropdown-item">
					<div class="item-avatar">
						<?php reign_notifications_avatar(); ?>
					</div>
					<div class="item-info">
						<div class="dropdown-item-title notification ellipsis"><?php bp_the_notification_description(); ?></div>
						<p class="mute"><?php bp_the_notification_time_since(); ?></p>
					</div>
					</div>
				<?php endwhile; 
			else : ?>
				<div class="alert-message">
					<div class="alert alert-warning" role="alert"><?php esc_html_e( 'No notifications found', 'reign' ); ?></div>
				</div>
			<?php endif; 
		
		$response['contents']			= ob_get_clean();
		$response['total_notifications']= bp_notifications_get_unread_notification_count( bp_displayed_user_id() );
		wp_send_json_success( $response );
	}

	add_action( 'wp_ajax_reign_theme_unread_notification', 'reign_theme_set_unread_notification' );
}