<?php
/* * * Social fields ** */

add_action( 'after_switch_theme', 'reign_rtm_set_default_social_fields' );
function reign_rtm_set_default_social_fields () {
	global $wbtm_reign_settings;
	$wbtm_social_links	 = isset( $wbtm_reign_settings[ 'reign_buddyextender' ][ 'wbtm_social_links' ] ) ? $wbtm_reign_settings[ 'reign_buddyextender' ][ 'wbtm_social_links' ] : array();
	if( empty( $wbtm_social_links ) ) {
		$wbtm_social_links = array(
			'facebook' => array(
				'img_url'	=>	'',
				'name'	=>	__( 'Facebook', 'reign' ),
			),
			'twitter' => array(
				'img_url'	=>	'',
				'name'	=>	__( 'Twitter', 'reign' ),
			),
			'linkedin' => array(
				'img_url'	=>	'',
				'name'	=>	__( 'Linkedin', 'reign' ),
			)
		);
		$wbtm_reign_settings[ 'reign_buddyextender' ][ 'wbtm_social_links' ] = $wbtm_social_links;
		update_option( "reign_options", $wbtm_reign_settings );
		$wbtm_reign_settings = get_option( "reign_options", array() );
	}
}

/**
 * Save the user social fields data
 * @since Reign 1.0.0
 * */
add_action( "xprofile_updated_profile", "reign_user_social_fields_save", 1, 3 );

function reign_user_social_fields_save( $user_id, $posted_field_ids, $errors ) {
	if ( empty( $user_id ) ) { // no user ah! skip it then.
		return;
	}
	$socials = get_user_meta( $user_id, "wbtm_user_social_links", true );
	if ( !is_array( $socials ) ) {
		$socials = array();
	}
	if ( isset( $_POST[ "wbtm_user_social_links" ] ) && $_POST[ "wbtm_user_social_links" ] == "1" ) {
		foreach ( reign_get_user_social_array() as $field_slug => $social ) {
			$slug	 = $field_slug;
			$url	 = $_POST[ "wbcom_social_" . $slug ];
			//check if its valid URL
			if ( filter_var( $url, FILTER_VALIDATE_URL ) || empty( $url ) ) {
				$socials[ $slug ] = $url;
				update_user_meta( $user_id, $slug, $url ); //update it
			}
		}
		update_user_meta( $user_id, "wbtm_user_social_links", $socials ); //update it
	}
}

add_action( "bp_after_profile_field_content", "reign_user_social_fields" );

function reign_user_social_fields( $user_id = false ) {
	if ( !$user_id ) {
		$user_id = bp_displayed_user_id();
	}
	/* field will only shown on base.
	 * so if in case we are on somewhere else then skip it !
	 *
	 * It's safe enough to assume that 'base' profile group will always be there and its id will be 1,
	 * since there's no apparent way of deleting this field group.
	 */
	if ( !function_exists( 'bp_get_the_profile_group_id' ) || ( function_exists( 'bp_get_the_profile_group_id' ) && bp_get_the_profile_group_id() != 1 ) ) {
		return;
	}
        global $wbtm_reign_settings;
	$socials = (array) get_user_meta( $user_id, "wbtm_user_social_links", true );
	$socials = apply_filters( "reign_get_user_social_array", $socials, $user_id );
        if ( isset($wbtm_reign_settings['reign_buddyextender']['enable_profile_social_links']) && $wbtm_reign_settings['reign_buddyextender']['enable_profile_social_links'] == 'on' ) {
            if ( 'edit' == bp_current_action() ) {
                    ?>
                    <div class="editfield field_name required-field visibility-public field_type_textbox">
                            <fieldset>
                                    <legend><?php esc_html_e( 'Social', 'reign' ); ?></legend>
                                    <div class="wbcom-user-social">
                                            <input type="hidden" name="wbtm_user_social_links" value="1">
                                            <?php foreach ( reign_get_user_social_array() as $field_slug => $social ) { ?>
                                                    <div class="bp-profile-field editfield field_type_textbox field_<?php echo $field_slug; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?>">
                                                            <label for="wbcom_social_<?php echo $field_slug; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?>"><?php echo $social[ 'name' ]; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?></label>
                                                            <input id="wbcom_social_<?php echo $field_slug; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?>" name="wbcom_social_<?php echo $field_slug; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?>" type="text" value="<?php echo esc_attr( @$socials[ $field_slug ] ); ?>" />
                                                    </div>
                                            <?php } ?>
                                    </div>
                            </fieldset>
                    </div>
                    <?php
            } else {
                    $val = reign_get_user_social_array();
                    if ( reign_array_not_all_empty( $socials, $val ) and ! empty( $val ) ) {
                            ?>
                            <div class="bp-widget social">
                                    <h2><?php esc_html_e( 'Social', 'reign' ); ?></h2>
                                    <table class="profile-fields">
                                            <tbody>
                                                    <?php foreach ( reign_get_user_social_array() as $field_slug => $social ) : ?>
                                                            <?php
                                                            if ( !isset( $socials[ $field_slug ] ) ) {
                                                                    continue;
                                                            }
                                                            $field_value = $socials[ $field_slug ];
                                                            if ( empty( $field_value ) ) {
                                                                    continue;
                                                            }
                                                            $field_value = make_clickable( $field_value );
                                                            ?>
                                                            <tr class="field_type_textbox field_<?php echo $field_slug; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?>">
                                                                    <td class="label"><?php echo $social[ 'name' ]; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?></td>
                                                                    <td class="data"><?php echo $field_value; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?></td>
                                                            </tr>
                                                    <?php endforeach; ?>
                                            </tbody>
                                    </table>
                            </div>
                            <?php
                    }
            }
        }
}

function reign_get_user_social_array() {
	global $wbtm_reign_settings;
	$wbtm_social_links	 = isset( $wbtm_reign_settings[ 'reign_buddyextender' ][ 'wbtm_social_links' ] ) ? $wbtm_reign_settings[ 'reign_buddyextender' ][ 'wbtm_social_links' ] : array();
	return $wbtm_social_links;
}

function reign_array_not_all_empty( $xprofile_links, $backend_keys ) {
	foreach ($backend_keys as $key => $value) {
		if( isset( $xprofile_links[$key] ) && !empty( $xprofile_links[$key] ) ) {
			return true;
		}
	}
	return false;
}