<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

if ( ! class_exists( 'Reign_Wbcom_Support_Tab' ) ) :

	/**
	 * @class Reign_Wbcom_Support_Tab
	 */
	class Reign_Wbcom_Support_Tab {

		/**
		 * The single instance of the class.
		 *
		 * @var Reign_Wbcom_Support_Tab
		 */
		protected static $_instance = null;
		protected static $_slug     = 'wbcom-support';

		/**
		 * Main Reign_Wbcom_Support_Tab Instance.
		 *
		 * Ensures only one instance of Reign_Wbcom_Support_Tab is loaded or can be loaded.
		 *
		 * @return Reign_Wbcom_Support_Tab - Main instance.
		 */
		public static function instance() {
			if ( is_null( self::$_instance ) ) {
				self::$_instance = new self();
			}
			return self::$_instance;
		}

		/**
		 * Reign_Wbcom_Support_Tab Constructor.
		 */
		public function __construct() {
			$this->init_hooks();
		}

		/**
		 * Hook into actions and filters.
		 */
		private function init_hooks() {
			add_filter( 'alter_reign_admin_tabs', array( $this, 'alter_reign_admin_tabs' ), 50, 1 );
			add_action( 'render_content_after_form', array( $this, 'render_get_started_with_customization_section' ), 10, 1 );

			add_action( 'admin_menu', array( $this, 'add_reign_setting_submenu' ), 50 );
		}

		public function add_reign_setting_submenu() {
			add_submenu_page(
				'reign-settings',
				__( 'Support', 'reign' ),
				__( 'Support', 'reign' ),
				'manage_options',
				admin_url( 'admin.php?page=reign-options&tab=' . self::$_slug )
			);
		}

		public function alter_reign_admin_tabs( $tabs ) {
			$tabs[ self::$_slug ] = __( 'Support', 'reign' );
			return $tabs;
		}

		public function render_get_started_with_customization_section( $tab ) {
			if ( $tab != self::$_slug ) {
				return;
			}
			?>
			<style type="text/css">
				div#rg-poststuff {
					display: none;
				}

				.reign_support_faq {
					background: #fff;
					padding: 1rem;
					overflow: hidden;
					border: 1px solid #ddd;
					border-top: 0;
				}

				.reign_support_faq .panel_left {
					float: left;
					width: 55%;
				}

				.reign_support_faq p {
					font-size: 18px;
				}

				.reign_support_faq.reign_support_faq_links p {
					font-size: 16px;
				}

				.reign_support_faq h2 {
					font-size: 20px;
					font-weight: 700;
					line-height: 1.2;
					margin: 0 0 1rem;
					padding-bottom: 1rem;
					color: #333;
					position: relative;
					display: -webkit-box;
					display: -ms-flexbox;
					display: flex;
					-webkit-box-align: center;
					-ms-flex-align: center;
					align-items: center;
				}

				.reign_support_faq.reign_support_faq_links h2 {
					font-size: 16px;
				}

				.reign_support_faq h2:before {
					content: "";
					font-family: dashicons;
					font-size: inherit;
					left: 0;
					background-color: #f6f6f6;
					height: 38px;
					width: 38px;
					border-radius: 50px;
					vertical-align: middle;
					margin-right: 15px;
					display: -webkit-inline-box;
					display: -ms-inline-flexbox;
					display: inline-flex;
					-webkit-box-align: center;
					-ms-flex-align: center;
					align-items: center;
					justify-content: center;
					-webkit-box-pack: center;
					-ms-flex-pack: center;
					justify-content: center;
					-webkit-box-flex: 0;
					-ms-flex: 0 0 auto;
					flex: 0 0 auto;
				}

				.reign_support_faq #faq-demo h2:before {
					content: "\f330";
				}

				.reign_support_faq #faq-create-ticket h2:before {
					content: "\f524";
				}

				.reign_support_faq #faq-custom-development h2:before {
					content: "\f475";
				}

				.reign_support_faq #faq-child-theme h2:before {
					content: "\f501";
				}

				.reign_support_faq .support_link_Section {
					position: relative;
					margin: 0;
					padding: 1rem;
					background: #fff;
					border: 1px solid #ddd;
				}

				.reign_support_faq.reign_support_faq_links {
					display: -webkit-box;
					display: -ms-flexbox;
					display: flex;
					-ms-flex-flow: row wrap;
					flex-flow: row wrap;
				}

				.reign_support_faq_links .support_link_Section {
					margin: 10px;
					width: calc(33.333333% - 20px);
				}

				.reign_support_faq .panel-right {
					float: right;
					width: 40%;
				}

				.reign_support_faq .panel-right img {
					max-width: 100%;
				}

				#faq-demo iframe {
					width: 100%;
				}

				.reign-feature-title .dashicons {
					margin-right: 10px;
					background: #333;
					color: #fff;
				}

				.reign-doc a {
					text-decoration: none;
					font-size: 16px;
					margin: 10px 0;
					display: block;
				}

				.reign-doc a:hover {
					text-decoration: underline;
				}

				.reign-doc a:hover span {
					text-decoration: none;
				}

				.reign-doc h2:before {
					content: "\f491";
				}

				@media (max-width: 991px) {
					.reign_support_faq_links .support_link_Section {
						width: calc(50% - 20px);
					}
				}

				@media (max-width: 769px) {
					.reign_support_faq_links .support_link_Section {
						width: 100%;
						margin: 10px 0;
					}
					.reign_support_faq .panel-right,
					.reign_support_faq .panel_left {
						width: 100%;
					}
					.reign_support_faq .panel_left {
						margin: 0 0 20px;
					}
				}

			</style>

			<script type="text/javascript">

			// Select all links with hashes
			jQuery( document ).ready( function () {
				// Add smooth scrolling to all links
				jQuery( "a" ).on( 'click', function ( event ) {

					// Make sure this.hash has a value before overriding default behavior
					if ( this.hash !== "" ) {
						// Prevent default anchor click behavior
						event.preventDefault();

						// Store hash
						var hash = this.hash;

						// Using jQuery's animate() method to add smooth page scroll
						// The optional number (800) specifies the number of milliseconds it takes to scroll to the specified area
						jQuery( 'html, body' ).animate( {
							scrollTop: jQuery( hash ).offset().top
						}, 800, function () {

							// Add hash (#) to URL when done scrolling (default click behavior)
							window.location.hash = hash;
						} );
					} // End if
				} );
			} );
			</script>

			<div class="reign_support_faq">
				<div class="panel_left">
					<div id="faq-demo" class="support_link_Section">
						<h2><?php _e( 'How to import demo data?', 'reign' ); ?></h2>
						<p><?php _e( 'The theme package includes demo data importer plugin allowing you to get started with ready to use website in just a few clicks. Find below the related video attached for a closer look and better understanding. For glance around the theme reach us to our knowledge base by <a href="https://wbcomdesigns.com/reign-knowledge-base/" target="_blank">click here</a>.', 'reign' ); ?></p>
						<p><?php _e( 'Watch the video below for getting quick idea.', 'reign' ); ?></p>
						<iframe width="560" height="315" src="https://www.youtube.com/embed/mVJhzckYupE" frameborder="0" allow="accelerometer; autoplay; encrypted-media; gyroscope; picture-in-picture" allowfullscreen></iframe>
					</div>
				</div>
				<div class="panel-right">
					<div class="reign-support-row reign-doc">
						<h2><?php esc_html_e( 'Documentation', 'reign' ); ?></h2>
							<a class="reign-btn" target="_blank" rel="noopener" href="<?php echo esc_url( 'https://wbcomdesigns.com/docs/reign-theme/getting-started/how-to-install-reign-theme/' ); ?>"><span class="dashicons dashicons-arrow-right"></span><?php esc_html_e( 'Reign Theme', 'reign' ); ?></a>
							<a class="reign-btn" target="_blank" rel="noopener" href="<?php echo esc_url( 'https://wbcomdesigns.com/docs/reign-theme/demo-import/reign-buddypress-demo-data-installation/' ); ?>"><span class="dashicons dashicons-arrow-right"></span><?php esc_html_e( 'Reign Theme - Demo Import', 'reign' ); ?></a>
							<a class="reign-btn" target="_blank" rel="noopener" href="<?php echo esc_url( 'https://wbcomdesigns.com/docs/reign-theme/header-styling/how-to-configure-site-header/' ); ?>"><span class="dashicons dashicons-arrow-right"></span><?php esc_html_e( 'Reign Theme - Header Styling', 'reign' ); ?></a>
							<a class="reign-btn" target="_blank" rel="noopener" href="<?php echo esc_url( 'https://wbcomdesigns.com/docs/reign-theme/sub-header-styling/sub-header-configuration/' ); ?>"><span class="dashicons dashicons-arrow-right"></span><?php esc_html_e( 'Reign Theme - Sub Header Styling', 'reign' ); ?></a>
							<a class="reign-btn" target="_blank" rel="noopener" href="<?php echo esc_url( 'https://wbcomdesigns.com/docs/reign-theme/rt-menu-configuration/configure-primary-and-user-menus/' ); ?>"><span class="dashicons dashicons-arrow-right"></span><?php esc_html_e( 'Reign Theme - Menu Configuration', 'reign' ); ?></a>
							<a class="reign-btn" target="_blank" rel="noopener" href="<?php echo esc_url( 'https://wbcomdesigns.com/docs/reign-theme/rt-top-bar-configuration/how-to-configure-default-topbar/' ); ?>"><span class="dashicons dashicons-arrow-right"></span><?php esc_html_e( 'Reign Theme - Top Bar Configuration', 'reign' ); ?></a>
							<a class="reign-btn" target="_blank" rel="noopener" href="<?php echo esc_url( 'https://wbcomdesigns.com/docs/reign-theme/rt-brand-configuration/how-to-set-favicon-site-title-and-tagline-for-the-website/' ); ?>"><span class="dashicons dashicons-arrow-right"></span><?php esc_html_e( 'Reign Theme - Brand Configuration', 'reign' ); ?></a>
							<a class="reign-btn" target="_blank" rel="noopener" href="<?php echo esc_url( 'https://wbcomdesigns.com/docs/reign-theme/rt-mobile-panel-configuration/change-color-scheme-for-mobile-left-right-panel/' ); ?>"><span class="dashicons dashicons-arrow-right"></span><?php esc_html_e( 'RT- Mobile Panel Configuration', 'reign' ); ?></a>
							<a class="reign-btn" target="_blank" rel="noopener" href="<?php echo esc_url( 'https://wbcomdesigns.com/docs/reign-theme/footer-configuration/configure-footer/' ); ?>"><span class="dashicons dashicons-arrow-right"></span><?php esc_html_e( 'Reign Theme - Footer Configuration', 'reign' ); ?></a>
							<a class="reign-btn" target="_blank" rel="noopener" href="<?php echo esc_url( 'https://wbcomdesigns.com/docs/reign-theme/rt-customizer-setting/homepage-settings/' ); ?>"><span class="dashicons dashicons-arrow-right"></span><?php esc_html_e( 'Reign Theme - Customizer Setting', 'reign' ); ?></a>
							<a class="reign-btn" target="_blank" rel="noopener" href="<?php echo esc_url( 'https://wbcomdesigns.com/docs/reign-theme/rt-theme-setting/buddypress-avatar-size-setting/' ); ?>"><span class="dashicons dashicons-arrow-right"></span><?php esc_html_e( 'Reign Theme - Theme Setting', 'reign' ); ?></a>
							<a class="reign-btn" target="_blank" rel="noopener" href="<?php echo esc_url( 'https://wbcomdesigns.com/docs/reign-theme/rt-buddypress-nouveau-option/directory-layouts/' ); ?>"><span class="dashicons dashicons-arrow-right"></span><?php esc_html_e( 'Reign Theme - BuddyPress Nouveau Option', 'reign' ); ?></a>
							<a class="reign-btn" target="_blank" rel="noopener" href="<?php echo esc_url( 'https://wbcomdesigns.com/docs/reign-theme/rt-additional-questions/increasing-the-wordpress-memory-limit/' ); ?>"><span class="dashicons dashicons-arrow-right"></span><?php esc_html_e( 'Reign Theme - Additional Questions', 'reign' ); ?></a>
							<a class="reign-btn" target="_blank" rel="noopener" href="<?php echo esc_url( 'https://wbcomdesigns.com/docs/reign-theme/peepso-configuration/how-can-i-verify-my-license/' ); ?>"><span class="dashicons dashicons-arrow-right"></span><?php esc_html_e( 'PeepSo Configuration', 'reign' ); ?></a>
							<a class="reign-btn" target="_blank" rel="noopener" href="<?php echo esc_url( 'https://wbcomdesigns.com/docs/reign-theme/reign-dokan-addon/reign-dokan-introduction/' ); ?>"><span class="dashicons dashicons-arrow-right"></span><?php esc_html_e( 'Reign Dokan Addon', 'reign' ); ?></a>
							<a class="reign-btn" target="_blank" rel="noopener" href="<?php echo esc_url( 'https://wbcomdesigns.com/docs/reign-theme/reign-wc-vendors-addon/reign-wc-vendor-introduction/' ); ?>"><span class="dashicons dashicons-arrow-right"></span><?php esc_html_e( 'Reign WC Vendors Addon', 'reign' ); ?></a>
							<a class="reign-btn" target="_blank" rel="noopener" href="<?php echo esc_url( 'https://wbcomdesigns.com/docs/reign-theme/reign-wp-job-manager-addon/installing-demo-content/' ); ?>"><span class="dashicons dashicons-arrow-right"></span><?php esc_html_e( 'Reign WP Job Manager Addon', 'reign' ); ?></a>
							<a class="reign-btn" target="_blank" rel="noopener" href="<?php echo esc_url( 'https://wbcomdesigns.com/docs/reign-theme/reign-learndash-addon/reign-learndash-addon-introduction/' ); ?>"><span class="dashicons dashicons-arrow-right"></span><?php esc_html_e( 'Reign Learndash Addon', 'reign' ); ?></a>
							<a class="reign-btn" target="_blank" rel="noopener" href="<?php echo esc_url( 'https://wbcomdesigns.com/docs/reign-theme/reign-wcfm-addon/reign-wcfm-introduction/' ); ?>"><span class="dashicons dashicons-arrow-right"></span><?php esc_html_e( 'Reign WCFM Addon', 'reign' ); ?></a>
							<a class="reign-btn" target="_blank" rel="noopener" href="<?php echo esc_url( 'https://wbcomdesigns.com/docs/reign-theme/reign-tutorlms-addon/reign-tutorlms-addon/' ); ?>"><span class="dashicons dashicons-arrow-right"></span><?php esc_html_e( 'Reign TutorLMS Addon', 'reign' ); ?></a>
							<a class="reign-btn" target="_blank" rel="noopener" href="<?php echo esc_url( 'https://wbcomdesigns.com/docs/reign-theme/reign-lifter-lms-addon/how-to-set-lifterlms-extra-widgets/' ); ?>"><span class="dashicons dashicons-arrow-right"></span><?php esc_html_e( 'Reign Lifter LMS Addon', 'reign' ); ?></a>
					</div>
				</div>
			</div>
			<div class="reign_support_faq reign_support_faq_links">
				<div id="faq-create-ticket" class="support_link_Section">
					<h2><?php _e( 'Create ticket', 'reign' ); ?></h2>
					<p><?php _e( 'We care about all our clients. Feel free to reach our <a href="https://wbcomdesigns.com/support/" target="_blank">support</a> for any kind of help, we would be only too happy to answer. Always there for you in need.', 'reign' ); ?></p>
				</div>
				<div id="faq-custom-development" class="support_link_Section">
					<h2><?php _e( 'Looking for additional Features?', 'reign' ); ?></h2>
					<p><?php _e( '<a href="https://wbcomdesigns.com/start-a-project/" target="_blank">Hire us!</a> For anything in WordPress and BuddyPress. Bringing ideas to life OR more life to your ideas?.</a>. Our team will love to help you.', 'reign' ); ?></p>
				</div>
				<div id="faq-child-theme" class="support_link_Section">
					<h2><?php _e( 'Reign Child theme', 'reign' ); ?></h2>
					<p><?php _e( 'If you are going to be making advanced edits to this theme, the best way is to use a child theme. Luckily I’ve already created a child theme for you. You can download the <a href="https://wbcomdesigns.com/wp-content/uploads/2020/01/reign-child-theme.zip" target="_blank">child theme here</a>.', 'reign' ); ?></p>
					<p><?php _e( 'Also you get the child theme from <a href="https://github.com/wbcomdesigns/reign-child-theme" target="_blank">github</a>.', 'reign' ); ?></p>
				</div>
			</div>
			<?php
		}

	}

	endif;

/**
 * Main instance of Reign_Wbcom_Support_Tab.
 *
 * @return Reign_Wbcom_Support_Tab
 */
Reign_Wbcom_Support_Tab::instance();
