<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

if ( ! class_exists( 'Reign_Kirki_Dark_Mode' ) ) :

/**
 * @class Reign_Kirki_Dark_Mode
 */
class Reign_Kirki_Dark_Mode {
	
	/**
	 * The single instance of the class.
	 *
	 * @var Reign_Kirki_Dark_Mode
	 */
	protected static $_instance = null;
	
	/**
	 * Main Reign_Kirki_Dark_Mode Instance.
	 *
	 * Ensures only one instance of Reign_Kirki_Dark_Mode is loaded or can be loaded.
	 *
	 * @return Reign_Kirki_Dark_Mode - Main instance.
	 */
	public static function instance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}
	
	/**
	 * Reign_Kirki_Dark_Mode Constructor.
	 */
	public function __construct() {
		$this->init_hooks();
	}

	/**
	 * Hook into actions and filters.
	 */
	private function init_hooks() {
		add_action( 'customize_register', array( $this, 'add_panels_and_sections' ) );
		add_filter( 'kirki/fields', array( $this, 'add_fields' ) );
	}

	public function add_panels_and_sections( $wp_customize ) {
    
		$wp_customize->add_section(
			'reign_dark_mode_options',
			array(
				'title'       => __( 'Dark Mode Option', 'reign' ),
				'priority'    => 10,
				'panel'       => 'reign_general_panel',
				'description' => '',
			)
		);

	}

	public function add_fields( $fields ) {

		$fields[] = array(
			'type'        => 'switch',
			'settings'    => 'reign_dark_mode_option',
			'label'       => esc_attr__( 'Dark Mode Toggle', 'reign' ),
			'description' => esc_attr__( 'Note: Option not working when activate color scheme \'Dark\' from colors settings.', 'reign' ),
			'section'     => 'reign_dark_mode_options',
			'priority'    => 10,
			'default'     => '',
                        'choices'     => array(
                                'on'	 => esc_attr__( 'Enable', 'reign' ),
                                'off'	 => esc_attr__( 'Disable', 'reign' ),
                        ),
		);
                
                $fields[] = array(
			'type'        => 'switch',
			'settings'    => 'reign_custom_dark_mode_option',
			'label'       => esc_attr__( 'Custom Dark Mode Colors', 'reign' ),
			'description' => esc_attr__( 'If enable this option, you can set custom colors from Customizer Setting > Colors > Color Scheme > Dark.', 'reign' ),
			'section'     => 'reign_dark_mode_options',
			'priority'    => 10,
			'default'     => '',
                        'choices'     => array(
                                'on'	 => esc_attr__( 'Enable', 'reign' ),
                                'off'	 => esc_attr__( 'Disable', 'reign' ),
                        ),
                        'active_callback' => array(
                                array(
                                        'setting'	 => 'reign_dark_mode_option',
                                        'operator'	 => '===',
                                        'value'		 => true,
                                ),
                        ),
		);
                
                $fields[] = array(
			'type'        => 'image',
			'settings'    => 'reign_dark_mode_logo',
			'label'       => esc_attr__( 'Dark Mode Logo', 'reign' ),
			'description' => esc_attr__( 'Set dark mode logo (Note: First set theme logo from Site Identity > Logo)', 'reign' ),
			'section'     => 'reign_dark_mode_options',
			'priority'    => 10,
			'default'     => '',
                        'active_callback' => array(
                                array(
                                        'setting'	 => 'reign_dark_mode_option',
                                        'operator'	 => '===',
                                        'value'		 => true,
                                ),
                        ),
		);
                
		return $fields;
	}
		
}

endif;

/**
 * Main instance of Reign_Kirki_Dark_Mode.
 * @return Reign_Kirki_Dark_Mode
 */
Reign_Kirki_Dark_Mode::instance();