<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

if ( ! class_exists( 'Reign_Kirki_Login_Popup' ) ) :

	/**
	 * @class Reign_Kirki_Login_Popup
	 */
	class Reign_Kirki_Login_Popup {

		/**
		 * The single instance of the class.
		 *
		 * @var Reign_Kirki_Login_Popup
		 */
		protected static $_instance = null;

		/**
		 * Main Reign_Kirki_Login_Popup Instance.
		 *
		 * Ensures only one instance of Reign_Kirki_Login_Popup is loaded or can be loaded.
		 *
		 * @return Reign_Kirki_Login_Popup - Main instance.
		 */
		public static function instance() {
			if ( is_null( self::$_instance ) ) {
				self::$_instance = new self();
			}
			return self::$_instance;
		}

		/**
		 * Reign_Kirki_Login_Popup Constructor.
		 */
		public function __construct() {
			$this->init_hooks();
		}

		/**
		 * Hook into actions and filters.
		 */
		private function init_hooks() {
			add_action( 'customize_register', array( $this, 'add_panels_and_sections' ) );
			add_filter( 'kirki/fields', array( $this, 'add_fields' ) );
		}

		public function add_panels_and_sections( $wp_customize ) {

			$wp_customize->add_section(
				'reign_signin_popup_options',
				array(
					'title'       => __( 'Sign-in Popup | Register Form Fields', 'reign' ),
					'priority'    => 10,
					'panel'       => 'reign_general_panel',
					'description' => '',
				)
			);
		}

		public function add_fields( $fields ) {

			$fields[] = array(
				'type'        => 'switch',
				'settings'    => 'reign_signin_popup',
				'label'       => esc_attr__( 'Sign-in Popup', 'reign' ),
				'description' => esc_attr__( '', 'reign' ),
				'section'     => 'reign_signin_popup_options',
				'priority'    => 10,
				'default'     => '',
				'choices'     => array(
					'on'  => esc_attr__( 'Enable', 'reign' ),
					'off' => esc_attr__( 'Disable', 'reign' ),
				),
			);

			$fields[] = array(
				'type'            => 'radio',
				'settings'        => 'reign_sign_form_popup',
				'label'           => esc_attr__( 'Form Popup', 'reign' ),
				'description'     => esc_attr__( '', 'reign' ),
				'section'         => 'reign_signin_popup_options',
				'priority'        => 10,
				'default'         => 'default',
				'choices'         => array(
					'default' => esc_attr__( 'Reign Login Form', 'reign' ),
					'custom'  => esc_attr__( 'Custom shortcode', 'reign' ),
				),
				'active_callback' => array(
					array(
						'setting'  => 'reign_signin_popup',
						'operator' => '==',
						'value'    => true,
					),
				),
			);

			$fields[] = array(
				'type'            => 'select',
				'settings'        => 'reign_sign_form_display',
				'label'           => esc_attr__( 'Form Display', 'reign' ),
				'description'     => esc_attr__( '', 'reign' ),
				'section'         => 'reign_signin_popup_options',
				'priority'        => 10,
				'default'         => 'login',
				'choices'         => array(
					'both'     => esc_attr__( 'Both', 'reign' ),
					'login'    => esc_attr__( 'Login', 'reign' ),
					'register' => esc_attr__( 'Register', 'reign' ),
				),
				'active_callback' => array(
					array(
						'setting'  => 'reign_sign_form_popup',
						'operator' => '!=',
						'value'    => 'custom',
					),
					array(
						'setting'  => 'reign_signin_popup',
						'operator' => '==',
						'value'    => true,
					),
				),
			);
                        
                        if ( class_exists( 'BuddyPress' ) ) {
                            
                            $fields[] = array(
                                    'type'            => 'select',
                                    'settings'        => 'reign_login_redirect',
                                    'label'           => esc_attr__( 'Login Redirect', 'reign' ),
                                    'description'     => esc_attr__( '', 'reign' ),
                                    'section'         => 'reign_signin_popup_options',
                                    'priority'        => 10,
                                    'default'         => 'current',
                                    'choices'         => array(
                                            'current'  => esc_html__( 'Current page', 'reign' ),
                                            'profile'  => esc_html__( 'Profile page', 'reign' ),
                                            'activity' => esc_html__( 'Activity page', 'reign' ),
                                            'custom'   => esc_html__( 'Custom page', 'reign' ),
                                    ),
                                    'active_callback' => array(
                                            array(
                                                    'setting'  => 'reign_sign_form_popup',
                                                    'operator' => '!=',
                                                    'value'    => 'custom',
                                            ),
                                            array(
                                                    'setting'  => 'reign_signin_popup',
                                                    'operator' => '==',
                                                    'value'    => true,
                                            ),
                                    ),
                            );
                            
                        } else {
                            
                            $fields[] = array(
				'type'            => 'select',
				'settings'        => 'reign_login_redirect',
				'label'           => esc_attr__( 'Login Redirect', 'reign' ),
				'description'     => esc_attr__( '', 'reign' ),
				'section'         => 'reign_signin_popup_options',
				'priority'        => 10,
				'default'         => 'current',
				'choices'         => array(
					'current'  => esc_html__( 'Current page', 'reign' ),
					'custom'   => esc_html__( 'Custom page', 'reign' ),
				),
				'active_callback' => array(
					array(
						'setting'  => 'reign_sign_form_popup',
						'operator' => '!=',
						'value'    => 'custom',
					),
					array(
						'setting'  => 'reign_signin_popup',
						'operator' => '==',
						'value'    => true,
					),
				),
                            );
                            
                        }

			$fields[] = array(
				'type'            => 'link',
				'settings'        => 'reign_login_redirect_url',
				'label'           => esc_attr__( 'Login Custom URL', 'reign' ),
				'description'     => esc_attr__( '', 'reign' ),
				'section'         => 'reign_signin_popup_options',
				'priority'        => 10,
				'default'         => '',
				'active_callback' => array(
					array(
						'setting'  => 'reign_signin_popup',
						'operator' => '==',
						'value'    => true,
					),
					array(
						'setting'  => 'reign_sign_form_popup',
						'operator' => '!=',
						'value'    => 'custom',
					),
					array(
						'setting'  => 'reign_login_redirect',
						'operator' => '==',
						'value'    => 'custom',
					),
				),
			);

                        if ( ! class_exists( 'PeepSo' ) ) {
                            
                            if ( class_exists( 'BuddyPress' ) ) {
                            
                                $fields[] = array(
                                        'type'            => 'select',
                                        'settings'        => 'reign_register_redirect',
                                        'label'           => esc_attr__( 'Register Redirect', 'reign' ),
                                        'description'     => esc_attr__( '', 'reign' ),
                                        'section'         => 'reign_signin_popup_options',
                                        'priority'        => 10,
                                        'default'         => 'current',
                                        'choices'         => array(
                                                'current'  => esc_html__( 'Current page', 'reign' ),
                                                'profile'  => esc_html__( 'Profile page', 'reign' ),
                                                'activity' => esc_html__( 'Activity page', 'reign' ),
                                                'custom'   => esc_html__( 'Custom page', 'reign' ),
                                        ),
                                        'active_callback' => array(
                                                array(
                                                        'setting'  => 'reign_sign_form_popup',
                                                        'operator' => '!=',
                                                        'value'    => 'custom',
                                                ),
                                                array(
                                                        'setting'  => 'reign_signin_popup',
                                                        'operator' => '==',
                                                        'value'    => true,
                                                ),
                                        ),
                                );
                            
                            } else {
                                
                                $fields[] = array(
                                        'type'            => 'select',
                                        'settings'        => 'reign_register_redirect',
                                        'label'           => esc_attr__( 'Register Redirect', 'reign' ),
                                        'description'     => esc_attr__( '', 'reign' ),
                                        'section'         => 'reign_signin_popup_options',
                                        'priority'        => 10,
                                        'default'         => 'current',
                                        'choices'         => array(
                                                'current'  => esc_html__( 'Current page', 'reign' ),
                                                'custom'   => esc_html__( 'Custom page', 'reign' ),
                                        ),
                                        'active_callback' => array(
                                                array(
                                                        'setting'  => 'reign_sign_form_popup',
                                                        'operator' => '!=',
                                                        'value'    => 'custom',
                                                ),
                                                array(
                                                        'setting'  => 'reign_signin_popup',
                                                        'operator' => '==',
                                                        'value'    => true,
                                                ),
                                        ),
                                );
                                
                            }

                            $fields[] = array(
                                    'type'            => 'link',
                                    'settings'        => 'reign_register_redirect_url',
                                    'label'           => esc_attr__( 'Register Custom URL', 'reign' ),
                                    'description'     => esc_attr__( '', 'reign' ),
                                    'section'         => 'reign_signin_popup_options',
                                    'priority'        => 10,
                                    'default'         => '',
                                    'active_callback' => array(
                                            array(
                                                    'setting'  => 'reign_signin_popup',
                                                    'operator' => '==',
                                                    'value'    => true,
                                            ),
                                            array(
                                                    'setting'  => 'reign_sign_form_popup',
                                                    'operator' => '!=',
                                                    'value'    => 'custom',
                                            ),
                                            array(
                                                    'setting'  => 'reign_register_redirect',
                                                    'operator' => '==',
                                                    'value'    => 'custom',
                                            ),
                                    ),
                            );
                            
                        }

                        $fields[] = array(
                                'type'            => 'textarea',
                                'settings'        => 'reign_login_description',
                                'label'           => esc_attr__( 'Login Form Description', 'reign' ),
                                'description'     => esc_attr__( 'Note: Use only for Reign Login Form.', 'reign' ),
                                'section'         => 'reign_signin_popup_options',
                                'default'         => '',
                                'priority'        => 10,
                                'active_callback' => array(
                                        array(
                                                'setting'  => 'reign_sign_form_popup',
                                                'operator' => '==',
                                                'value'    => 'default',
                                        ),
                                        array(
                                                'setting'  => 'reign_signin_popup',
                                                'operator' => '==',
                                                'value'    => true,
                                        ),
                                ),
                        );

                        $fields[] = array(
                                'type'            => 'textarea',
                                'settings'        => 'reign_sign_form_shortcode',
                                'label'           => esc_attr__( 'Popup Content', 'reign' ),
                                'description'     => esc_attr__( 'You can use own custom HTML or shortcodes that will appear in popup box', 'reign' ),
                                'section'         => 'reign_signin_popup_options',
                                'priority'        => 10,
                                'active_callback' => array(
                                        array(
                                                'setting'  => 'reign_sign_form_popup',
                                                'operator' => '==',
                                                'value'    => 'custom',
                                        ),
                                        array(
                                                'setting'  => 'reign_signin_popup',
                                                'operator' => '==',
                                                'value'    => true,
                                        ),
                                ),
                        );
                        
                        if ( class_exists( 'BuddyPress' ) ) {

                                $fields[] = array(
                                        'type'            => 'custom',
                                        'settings'        => 'custom-signin-divider',
                                        'section'         => 'reign_signin_popup_options',
                                        'default'         => '<hr>',
                                        'active_callback' => array(
                                                array(
                                                        'setting'  => 'reign_signin_popup',
                                                        'operator' => '==',
                                                        'value'    => true,
                                                ),
                                        ),
                                );
                        
                                $fields[] = array(
                                        'type'            => 'custom',
                                        'settings'        => 'reign_regiter_form',
                                        'label'           => esc_attr__( 'Reign Register Form', 'reign' ),
                                        'section'         => 'reign_signin_popup_options',
                                        'active_callback' => array(
                                                array(
                                                        'setting'  => 'reign_signin_popup',
                                                        'operator' => '==',
                                                        'value'    => true,
                                                ),
                                        ),
                                );

                                $fields[] = array(
                                        'type'            => 'custom',
                                        'settings'        => 'reign_regiter_basic',
                                        'label'           => '<h5 style="font-style: italic; margin: 0;">' . __( '- Basic', 'reign' ) . '</h5>',
                                        'description'     => esc_attr__( 'Form is non-editable and consists of basic WP fields \'First name\', \'Last name\', \'Username\', \'Email\', \'Password\' fields.', 'reign' ),
                                        'section'         => 'reign_signin_popup_options',
                                        'active_callback' => array(
                                                array(
                                                        'setting'  => 'reign_signin_popup',
                                                        'operator' => '==',
                                                        'value'    => true,
                                                ),
                                        ),
                                );

                                $fields[] = array(
                                        'type'            => 'custom',
                                        'settings'        => 'reign_regiter_standard',
                                        'label'           => '<h5 style="font-style: italic; margin: 0;">' . __( '- Standard', 'reign' ) . '</h5>',
                                        'description'     => esc_attr__( 'Form is editable via Users > Profile fields. Only the required field will be displayed in the form. \'Username\', \'Email\', \'Password\' are non-editable fields.', 'reign' ),
                                        'section'         => 'reign_signin_popup_options',
                                        'active_callback' => array(
                                                array(
                                                        'setting'  => 'reign_signin_popup',
                                                        'operator' => '==',
                                                        'value'    => true,
                                                ),
                                        ),
                                );
                        
                                if ( function_exists( 'bp_is_active' ) && bp_is_active( 'xprofile' ) ) {

                                        $fields[] = array(
                                                'type'            => 'custom',
                                                'settings'        => 'reign_regiter_extended',
                                                'label'           => '<h5 style="font-style: italic; margin: 0;">' . __( '- Extended', 'reign' ) . '</h5>',
                                                'description'     => esc_attr__( 'Form is editable via Users > Profile fields. Only the required field will be displayed in the form. After filling in form fields user will be redirected to the Register page, where can complete other Profile Info Fields \'Username\', \'Email\' are non-editable fields.', 'reign' ),
                                                'section'         => 'reign_signin_popup_options',
                                                'active_callback' => array(
                                                        array(
                                                                'setting'  => 'reign_signin_popup',
                                                                'operator' => '==',
                                                                'value'    => true,
                                                        ),
                                                ),
                                        );

                                        $fields[] = array(
                                                'type'            => 'radio',
                                                'settings'        => 'reign_sign_in_register_fields_type',
                                                'label'           => esc_attr__( '', 'reign' ),
                                                'description'     => esc_attr__( '', 'reign' ),
                                                'section'         => 'reign_signin_popup_options',
                                                'priority'        => 10,
                                                'default'         => 'simple',
                                                'choices'         => array(
                                                        'simple'    => esc_attr__( 'Basic', 'reign' ),
                                                        'buddypress' => esc_attr__( 'Standard', 'reign' ),
                                                        'extensional' => esc_attr__( 'Extended', 'reign' ),
                                                ),
                                                'active_callback' => array(
                                                        array(
                                                                'setting'  => 'reign_signin_popup',
                                                                'operator' => '==',
                                                                'value'    => true,
                                                        ),
                                                ),
                                        );

                                } else {

                                    $fields[] = array(
                                            'type'            => 'radio',
                                            'settings'        => 'reign_sign_in_register_fields_type',
                                            'label'           => esc_attr__( '', 'reign' ),
                                            'description'     => esc_attr__( '', 'reign' ),
                                            'section'         => 'reign_signin_popup_options',
                                            'priority'        => 10,
                                            'default'         => 'simple',
                                            'choices'         => array(
                                                    'simple'    => esc_attr__( 'Basic', 'reign' ),
                                                    'buddypress' => esc_attr__( 'Standard', 'reign' ),
                                            ),
                                            'active_callback' => array(
                                                    array(
                                                            'setting'  => 'reign_signin_popup',
                                                            'operator' => '==',
                                                            'value'    => true,
                                                    ),
                                            ),
                                    );

                                }

                                $fields[] = array(
                                        'type'        => 'switch',
                                        'settings'    => 'sign_in_register_activation_email',
                                        'label'       => esc_attr__( 'Activation Email', 'reign' ),
                                        'description' => esc_attr__( '', 'reign' ),
                                        'section'     => 'reign_signin_popup_options',
                                        'priority'    => 10,
                                        'default'     => 1,
                                        'choices'     => array(
                                                'on'  => esc_attr__( 'Enable', 'reign' ),
                                                'off' => esc_attr__( 'Disable', 'reign' ),
                                        ),
                                        'active_callback' => array(
                                                array(
                                                        'setting'  => 'reign_signin_popup',
                                                        'operator' => '==',
                                                        'value'    => true,
                                                ),
                                        ),
                                );
                        
                        }

                        return $fields;
		}

	}

	endif;

/**
 * Main instance of Reign_Kirki_Login_Popup.
 *
 * @return Reign_Kirki_Login_Popup
 */
Reign_Kirki_Login_Popup::instance();