<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

if ( ! class_exists( 'Reign_Kirki_Site_Layout' ) ) :

	/**
	 * @class Reign_Kirki_Site_Layout
	 */
	class Reign_Kirki_Site_Layout {

		/**
		 * The single instance of the class.
		 *
		 * @var Reign_Kirki_Site_Layout
		 */
		protected static $_instance = null;

		/**
		 * Main Reign_Kirki_Site_Layout Instance.
		 *
		 * Ensures only one instance of Reign_Kirki_Site_Layout is loaded or can be loaded.
		 *
		 * @return Reign_Kirki_Site_Layout - Main instance.
		 */
		public static function instance() {
			if ( is_null( self::$_instance ) ) {
				self::$_instance = new self();
			}
			return self::$_instance;
		}

		/**
		 * Reign_Kirki_Site_Layout Constructor.
		 */
		public function __construct() {
			$this->init_hooks();
		}

		/**
		 * Hook into actions and filters.
		 */
		private function init_hooks() {
			add_action( 'customize_register', array( $this, 'add_panels_and_sections' ) );
			add_filter( 'kirki/fields', array( $this, 'add_fields' ) );
		}

		public function add_panels_and_sections( $wp_customize ) {

			$wp_customize->add_section(
				'reign_site_layout_options',
				array(
					'title'       => __( 'Layouts', 'reign' ),
					'priority'    => 10,
					'panel'       => 'reign_general_panel',
					'description' => '',
				)
			);
		}

		public function add_fields( $fields ) {

			$fields[] = array(
				'type'        => 'switch',
				'settings'    => 'reign_enable_preloading',
				'label'       => esc_attr__( 'Site Loader', 'reign' ),
				'description' => esc_attr__( 'Show loader before loading content.', 'reign' ),
				'section'     => 'reign_site_layout_options',
				'default'     => 0,
				'priority'    => 10,
				'choices'     => array(
					'on'  => esc_attr__( 'Enable', 'reign' ),
					'off' => esc_attr__( 'Disable', 'reign' ),
				),
			);

			$fields[] = array(
				'type'            => 'radio-image',
				'settings'        => 'reign_preloading_icon',
				'label'           => esc_attr__( 'Loader Icon', 'reign' ),
				'description'     => '',
				'section'         => 'reign_site_layout_options',
				'default'         => REIGN_THEME_URI . '/lib/images/loader-1.svg',
				'priority'        => 10,
				'choices'         => array(
					REIGN_THEME_URI . '/lib/images/loader-1.svg' => REIGN_THEME_URI . '/lib/images/loader-1.svg',
					REIGN_THEME_URI . '/lib/images/loader-2.svg' => REIGN_THEME_URI . '/lib/images/loader-2.svg',
					REIGN_THEME_URI . '/lib/images/loader-3.svg' => REIGN_THEME_URI . '/lib/images/loader-3.svg',
					REIGN_THEME_URI . '/lib/images/loader-4.svg' => REIGN_THEME_URI . '/lib/images/loader-4.svg',
					REIGN_THEME_URI . '/lib/images/loader-5.svg' => REIGN_THEME_URI . '/lib/images/loader-5.svg',
					REIGN_THEME_URI . '/lib/images/loader-6.svg' => REIGN_THEME_URI . '/lib/images/loader-6.svg',
				),
				'active_callback' => array(
					array(
						'setting'  => 'reign_enable_preloading',
						'operator' => '===',
						'value'    => true,
					),
				),
			);

			$fields[] = array(
				'type'            => 'color',
				'settings'        => 'reign_preloading_bg_color',
				'label'           => esc_attr__( 'Loader Background Color', 'reign' ),
				'description'     => '',
				'section'         => 'reign_site_layout_options',
				'default'         => '#ffffff',
				'priority'        => 10,
				'choices'         => array( 'alpha' => true ),
				'active_callback' => array(
					array(
						'setting'  => 'reign_enable_preloading',
						'operator' => '===',
						'value'    => true,
					),
				),
			);

			$fields[] = array(
				'type'        => 'switch',
				'settings'    => 'reign_enable_scrollup',
				'label'       => esc_attr__( 'Site Scroll Up', 'reign' ),
				'description' => esc_attr__( '', 'reign' ),
				'section'     => 'reign_site_layout_options',
				'default'     => '',
				'priority'    => 10,
				'choices'     => array(
					'on'  => esc_attr__( 'Enable', 'reign' ),
					'off' => esc_attr__( 'Disable', 'reign' ),
				),
			);

			$fields[] = array(
				'type'            => 'radio',
				'settings'        => 'reign_scrollup_position',
				'label'           => esc_attr__( 'Scroll Up Position', 'reign' ),
				'description'     => esc_attr__( 'Select scroll up position left or right side.', 'reign' ),
				'section'         => 'reign_site_layout_options',
				'default'         => 'right',
				'priority'        => 10,
				'choices'         => array(
					'left'  => esc_attr__( 'Left', 'reign' ),
					'right' => esc_attr__( 'Right', 'reign' ),
				),
				'active_callback' => array(
					array(
						'setting'  => 'reign_enable_scrollup',
						'operator' => '===',
						'value'    => true,
					),
				),
			);

			$fields[] = array(
				'type'        => 'radio-image',
				'settings'    => 'reign_site_layout',
				'label'       => esc_attr__( 'Site Layout', 'reign' ),
				'description' => esc_attr__( 'Select site layout.', 'reign' ),
				'section'     => 'reign_site_layout_options',
				'default'     => 'full_width',
				'priority'    => 10,
				'choices'     => array(
					'full_width' => REIGN_THEME_URI . '/lib/images/full-width.jpg',
					'box_width'  => REIGN_THEME_URI . '/lib/images/box-width.jpg',
				),
			);

			// $fields[] = array(
			// 'type'        => 'switch',
			// 'settings'    => 'reign_site_enable_header_image',
			// 'label'       => esc_attr__( 'Enable Header Image', 'reign' ),
			// 'description'       => '',
			// 'section'     => 'reign_site_layout_options',
			// 'default'   => 1,
			// 'priority'    => 10,
			// 'choices'     => array(
			// 'on'  => esc_attr__( 'Enable', 'reign' ),
			// 'off' => esc_attr__( 'Disable', 'reign' ),
			// ),
			// );

			$fields[] = array(
				'type'        => 'switch',
				'settings'    => 'reign_sticky_sidebar',
				'label'       => esc_attr__( 'Sticky Sidebar', 'reign' ),
				'description' => '',
				'section'     => 'reign_site_layout_options',
				'default'     => 1,
				'priority'    => 10,
				'choices'     => array(
					'on'  => esc_attr__( 'Enable', 'reign' ),
					'off' => esc_attr__( 'Disable', 'reign' ),
				),
			);

			$fields[] = array(
				'type'        => 'dimension',
				'settings'    => 'site_container_width',
				'label'       => esc_attr__( 'Site Container Width', 'reign' ),
				'description' => esc_attr__( 'Set the width of the site container ( px or % ). Default is 1170px.', 'reign' ),
				'section'     => 'reign_site_layout_options',
				'default'     => '1170px',
				'priority'    => 10,
				'transport'   => 'auto',
				'output'      => array(
					array(
						'element'  => '.container, .container-fluid, .reign-stretched_view .footer-wrap .container, .reign-stretched_view_no_title .footer-wrap .container, .reign-stretched_view .reign-header-top .container, .reign-stretched_view_no_title .reign-header-top .container, .reign-stretched_view .reign-fallback-header .container, .reign-stretched_view_no_title .reign-fallback-header .container, .reign-peepso-group.layout-full-width .ps-focus__cover-inner, .reign-peepso-group.layout-full-width .ps-focus__info, .reign-peepso-group.layout-full-width .ps-focus__menu-inner, .reign-peepso-profile.layout-full-width .ps-focus__cover-inner, .reign-peepso-profile.layout-full-width .ps-focus__info, .reign-peepso-profile.layout-full-width .ps-focus__menu-inner, .reign-peepso-profile.layout-full-width .ps-badgeos__list-wrapper',
						'function' => 'css',
						'property' => 'max-width',
					),
				),
			);

			$fields[] = array(
				'type'        => 'dimension',
				'settings'    => 'site_sidebar_width',
				'label'       => esc_attr__( 'Site Sidebar Width', 'reign' ),
				'description' => esc_attr__( 'Set the width of the sidebar ( px or % ). Default is 28.125%.', 'reign' ),
				'section'     => 'reign_site_layout_options',
				'default'     => '28.125%',
				'priority'    => 10,
				'transport'   => 'auto',
				'output'      => array(
					array(
						'element'  => '.site-content .widget-area, .reign-both_sidebar aside#reign-sidebar-right, .reign-both_sidebar aside#reign-sidebar-left',
						'function' => 'css',
						'property' => 'max-width',
					),
				),
			);

			$fields[] = array(
				'type'        => 'switch',
				'settings'    => 'reign_global_border_radius_toggle',
				'label'       => esc_attr__( 'Global Border Radius', 'reign' ),
				'description' => '',
				'section'     => 'reign_site_layout_options',
				'priority'    => 10,
				'default'     => '',
				'choices'     => array(
					'on'  => esc_attr__( 'Enable', 'reign' ),
					'off' => esc_attr__( 'Disable', 'reign' ),
				),
			);

			$fields[] = array(
				'type'            => 'dimension',
				'settings'        => 'reign_global_border_radius_option',
				'label'           => esc_attr__( 'Site Global Border Radius', 'reign' ),
				'description'     => esc_attr__( 'Set the global border radius ( px ). Default is 3px.', 'reign' ),
				'section'         => 'reign_site_layout_options',
				'default'         => '3px',
				'priority'        => 10,
				'transport'       => 'auto',
				'output'          => array(
					array(
						'element'  => '.bp-nouveau .wbtm-cover-header-type-1 #header-cover-image:after, .bp-nouveau .wbtm-cover-header-type-2 #header-cover-image:after, .search-wrap .rg-search-form-wrap, .widget-area .widget, .user-welcomeback, .registration-login-form, .bp-nouveau .bp-list:not(.grid) > li, .bp-nouveau .buddypress-wrap .groups-list li .group-desc, .bp-nouveau .grid.bp-list > li .list-wrap, .bp-nouveau .activity-update-form:not(.modal-popup), .activity-update-form #whats-new-textarea textarea, .bp-nouveau .activity-list.bp-list .activity-item, form.ac-form .ac-reply-content .ac-textarea textarea, .bp-nouveau #buddypress div#item-header .wbtm-cover-header-type-1 div#item-header-cover-image, .bp-nouveau #buddypress .wbtm-cover-header-type-1 #header-cover-image, .bp-nouveau #buddypress div#item-header .wbtm-cover-header-type-1 div#item-header-cover-image:before, .bp-nouveau #buddypress .wbtm-cover-header-type-2 #header-cover-image, .bp-nouveau #buddypress div#item-header .wbtm-cover-header-type-2 div#item-header-cover-image, .bp-nouveau #buddypress div#item-header .wbtm-cover-header-type-2 .wbtm-cover-extra-info-section > div, .bp-nouveau #buddypress div#item-header .wbtm-cover-header-type-2 .wbtm-member-info-section, .bp-nouveau #buddypress div#item-header .wbtm-cover-header-type-3 div#item-header-cover-image, .bp-nouveau #buddypress div#item-header .wbtm-cover-header-type-4 div#item-header-cover-image, .bp-nouveau .groups-header .desc-wrap, .bp-nouveau .groups-header .desc-wrap .group-description, .blog .hentry, .archive:not(.geodir-page) .hentry:not(.forum):not(.topic):not(.tribe_events), .post-type-archive:not(.post-type-archive-tribe_events):not(.geodir-page) .hentry:not(.forum):not(.topic):not(.tribe_events) article, body.search .search-wrap:not(.rg-icon-wrap), .woocommerce ul.products li.product, .woocommerce-thankyou-order-received, .lm-course-item-wrapper, .lm-course-item-wrapper .lm-course-item, .reign-nav-swipe .main-navs:not(.vertical), .reign-nav-swipe .main-navs:not(.vertical) ul, #bbpress-forums ul.bbp-lead-topic, #bbpress-forums ul.bbp-topics, #bbpress-forums ul.bbp-forums, #bbpress-forums ul.bbp-replies, #bbpress-forums ul.bbp-search-results, #bbpress-forums .bbp-login-form fieldset.bbp-form, .bbp-reply-form, .bbp-topic-form, #bbpress-forums .rg-replies>li>div, .bp-nouveau .bp-vertical-navs .rg-nouveau-sidebar-menu, .bp-nouveau .bp-vertical-navs .item-body-inner-wrapper, .rg-nouveau-sidebar-menu.reign-nav-swipe .main-navs:not(.vertical) ul, #masthead .rg-woocommerce_mini_cart, #masthead .rg-edd_mini_cart, .header-notifications-dropdown-menu, #masthead .user-profile-menu, .primary-menu .children, .primary-menu .sub-menu, .bp-share-service-popup, .bp-nouveau #buddypress.buddypress-wrap.bp-dir-hori-nav #item-body #subnav, .bp-nouveau #send-invites-editor, .bp-nouveau .bp-member-add-form, .bp-nouveau .bptodo-adming-setting, .bp-nouveau .bptodo-form-add, .bp-nouveau .buddypress-wrap .profile, .bp-nouveau .bp-messages-content, .bp-nouveau .bupr-bp-member-reviews-block, .bp-nouveau form#account-capabilities-form, .bp-nouveau form#account-group-invites-form, .bp-nouveau form#group-settings-form, .bp-nouveau form#settings-form, .media .rtmedia-container,
						#pmpro_levels_table .rtm_pmpro_levels_plan .rtm_pmpro_levels_section, .pmpro_login_wrap, .pmpro_lost_password_wrap, .pmpro_reset_password_wrap, .pmpro_logged_in_welcome_wrap, #pmpro_form .pmpro_checkout, .pmpro-confirmation .pmpro-has-access>.entry-content, .pmpro_invoice_details>div, .pmpro-invoice .pmpro-has-access>.entry-content, .pmpro_member_profile_edit_wrap, .pmpro_change_password_wrap, #whats-new-form, .whats-new-form-header #whats-new-textarea',
						'function' => 'css',
						'property' => 'border-radius',
						'suffix'   => ' !important',
					),
					array(
						'element'  => '.bp-nouveau #header-cover-image:after, .bp-nouveau #buddypress .grid.bp-list.rg-member-list.wbtm-member-directory-type-2 .wbtm-mem-cover-img, .bp-nouveau #buddypress .grid.bp-list.rg-member-list.wbtm-member-directory-type-3 .wbtm-mem-cover-img, .bp-nouveau #buddypress.buddypress-wrap .grid.bp-list.wbtm-group-directory-type-2 .wbtm-group-cover-img, .bp-nouveau #buddypress.buddypress-wrap .grid.bp-list.wbtm-group-directory-type-3 .wbtm-group-cover-img, .bp-nouveau #buddypress .wbtm-cover-header-type-3 #header-cover-image, .bp-nouveau #buddypress .wbtm-cover-header-type-4 #header-cover-image, .woocommerce ul.products li.product a img',
						'function' => 'css',
						'property' => 'border-top-left-radius',
						'suffix'   => ' !important',
					),
					array(
						'element'  => '.bp-nouveau #header-cover-image:after, .bp-nouveau #buddypress .grid.bp-list.rg-member-list.wbtm-member-directory-type-2 .wbtm-mem-cover-img, .bp-nouveau #buddypress .grid.bp-list.rg-member-list.wbtm-member-directory-type-3 .wbtm-mem-cover-img, .bp-nouveau #buddypress.buddypress-wrap .grid.bp-list.wbtm-group-directory-type-2 .wbtm-group-cover-img, .bp-nouveau #buddypress.buddypress-wrap .grid.bp-list.wbtm-group-directory-type-3 .wbtm-group-cover-img, .bp-nouveau #buddypress .wbtm-cover-header-type-3 #header-cover-image, .bp-nouveau #buddypress .wbtm-cover-header-type-4 #header-cover-image, .woocommerce ul.products li.product a img, .woocommerce ul.products li.product .onsale',
						'function' => 'css',
						'property' => 'border-top-right-radius',
						'suffix'   => ' !important',
					),
					array(
						'element'  => '#whats-new-textarea, .activity-update-form #whats-new, .header-notifications-dropdown-menu .dropdown-footer a.button, .bp-nouveau .activity-list .activity-item .activity-content .activity-meta.action, .bp-nouveau .activity-list .activity-item .activity-content .bp-generic-meta.action',
						'function' => 'css',
						'property' => 'border-bottom-right-radius',
						'suffix'   => ' !important',
					),
					array(
						'element'  => '#whats-new-textarea, .activity-update-form #whats-new, .woocommerce ul.products li.product .onsale, .header-notifications-dropdown-menu .dropdown-footer a.button, .bp-nouveau .activity-list .activity-item .activity-content .activity-meta.action, .bp-nouveau .activity-list .activity-item .activity-content .bp-generic-meta.action',
						'function' => 'css',
						'property' => 'border-bottom-left-radius',
						'suffix'   => ' !important',
					),
				),
				'active_callback' => array(
					array(
						'setting'  => 'reign_global_border_radius_toggle',
						'operator' => '===',
						'value'    => true,
					),
				),
			);

			// Global Button Radius.
			// $fields[] = array(
			// 'type'        => 'switch',
			// 'settings'    => 'reign_global_button_radius_toggle',
			// 'label'       => esc_attr__( 'Global Button Radius', 'reign' ),
			// 'description' => 'Select the border radius of buttons.',
			// 'section'     => 'reign_site_layout_options',
			// 'priority'    => 10,
			// 'default'     => '',
			// 'choices'     => array(
			// 'on'  => esc_attr__( 'Enable', 'reign' ),
			// 'off' => esc_attr__( 'Disable', 'reign' ),
			// ),
			// );

			// $fields[] = array(
			// 'type'            => 'slider',
			// 'settings'        => 'reign_global_button_radius',
			// 'label'           => esc_attr__( 'Global Button Radius', 'reign' ),
			// 'description'     => 'Set the radius to "0" for a square button, "100" and any number in between for a rounded button, we recommend setting the button radius to "3".',
			// 'section'         => 'reign_site_layout_options',
			// 'priority'        => 10,
			// 'default'         => 3,
			// 'choices'         => array(
			// 'min'  => 0,
			// 'max'  => 100,
			// 'step' => 1,
			// ),
			// 'active_callback' => array(
			// array(
			// 'setting'  => 'reign_global_button_radius_toggle',
			// 'operator' => '===',
			// 'value'    => true,
			// ),
			// ),
			// );

			return $fields;
		}

	}

	endif;

/**
 * Main instance of Reign_Kirki_Site_Layout.
 *
 * @return Reign_Kirki_Site_Layout
 */
Reign_Kirki_Site_Layout::instance();
