<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

if ( ! class_exists( 'Reign_Kirki_Header_Mobile_Menu' ) ) :

	/**
	 * @class Reign_Kirki_Header_Mobile_Menu
	 */
	class Reign_Kirki_Header_Mobile_Menu {

		/**
		 * The single instance of the class.
		 *
		 * @var Reign_Kirki_Header_Mobile_Menu
		 */
		protected static $_instance = null;

		/**
		 * Main Reign_Kirki_Header_Mobile_Menu Instance.
		 *
		 * Ensures only one instance of Reign_Kirki_Header_Mobile_Menu is loaded or can be loaded.
		 *
		 * @return Reign_Kirki_Header_Mobile_Menu - Main instance.
		 */
		public static function instance() {
			if ( is_null( self::$_instance ) ) {
				self::$_instance = new self();
			}
			return self::$_instance;
		}

		/**
		 * Reign_Kirki_Header_Mobile_Menu Constructor.
		 */
		public function __construct() {
			$this->init_hooks();
		}

		/**
		 * Hook into actions and filters.
		 */
		private function init_hooks() {
			add_action( 'customize_register', array( $this, 'add_panels_and_sections' ) );
			add_filter( 'kirki/fields', array( $this, 'add_fields' ) );
		}

		public function add_panels_and_sections( $wp_customize ) {

			$wp_customize->add_section(
				'reign_header_mobile_menu',
				array(
					'title'       => __( 'Mobile Menu', 'reign' ),
					'priority'    => 11,
					'panel'       => 'reign_header_panel',
					'description' => __( '', 'reign' ),
				)
			);
		}

		public function add_fields( $fields ) {

			$default_value_set = reign_get_customizer_default_value_set();

			$fields[] = array(
				'type'        => 'radio',
				'settings'    => 'reign_mobile_header_layout',
				'label'       => esc_attr__( 'Mobile Header Layout', 'reign' ),
				'description' => esc_attr__( 'Allows you to change mobile header layout.', 'reign' ),
				'section'     => 'reign_header_mobile_menu',
				'default'     => 'header-v1',
				'priority'    => 10,
				'choices'     => array(
					'header-v1' => esc_attr__( 'Layout One', 'reign' ),
					'header-v2' => esc_attr__( 'Layout Two', 'reign' ),
					'header-v3' => esc_attr__( 'Layout Three', 'reign' ),
				),
			);

			$fields[] = array(
				'type'        => 'switch',
				'settings'    => 'reign_header_mobile_menu_logo_enable',
				'label'       => esc_attr__( 'Config Mobile Logo', 'reign' ),
				'description' => esc_attr__( 'Allows you to config logo for mobile menu.', 'reign' ),
				'section'     => 'reign_header_mobile_menu',
				'default'     => 0,
				'priority'    => 10,
				'choices'     => array(
					'on'  => esc_attr__( 'Custom', 'reign' ),
					'off' => esc_attr__( 'Default', 'reign' ),
				),
			);

			$fields[] = array(
				'type'            => 'image',
				'settings'        => 'reign_header_mobile_menu_logo',
				'label'           => esc_attr__( 'Mobile Logo', 'reign' ),
				'description'     => esc_attr__( 'Allows you to add, remove, change mobile logo on your site.', 'reign' ),
				'section'         => 'reign_header_mobile_menu',
				'priority'        => 10,
				'default'         => '',
				'active_callback' => array(
					array(
						'setting'  => 'reign_header_mobile_menu_logo_enable',
						'operator' => '===',
						'value'    => true,
					),
				),
			);

			if ( class_exists( 'BuddyPress' ) && class_exists( 'WooCommerce' ) || class_exists( 'BuddyPress' ) && class_exists( 'Easy_Digital_Downloads' ) ) {

				$fields[] = array(
					'type'            => 'sortable',
					'settings'        => 'reign_mobile_header_icons_set',
					'label'           => esc_attr__( 'Mobile Header Icons Options', 'reign' ),
					'description'     => '',
					'section'         => 'reign_header_mobile_menu',
					'priority'        => 10,
					'default'         => $default_value_set['reign_mobile_header_icons_set'],
					'choices'         => array(
						'search'        => esc_html__( 'Search', 'reign' ),
						'cart'          => esc_html__( 'Cart', 'reign' ),
						'message'       => esc_html__( 'Message', 'reign' ),
						'notification'  => esc_html__( 'Notification', 'reign' ),
						'login'         => esc_html__( 'Login', 'reign' ),
						'register-menu' => esc_html__( 'Register', 'reign' ),
					),
					/* comment below to make layout meun icon section available for elementor header */
					'active_callback' => array(
						array(
							'setting'  => 'reign_header_header_type',
							'operator' => '!==',
							'value'    => true,
						),
					),
				);

			} elseif ( class_exists( 'WooCommerce' ) || class_exists( 'Easy_Digital_Downloads' ) ) {

				$fields[] = array(
					'type'            => 'sortable',
					'settings'        => 'reign_mobile_header_icons_set',
					'label'           => esc_attr__( 'Mobile Header Icons Options', 'reign' ),
					'description'     => '',
					'section'         => 'reign_header_mobile_menu',
					'priority'        => 10,
					'default'         => $default_value_set['reign_mobile_header_icons_set'],
					'choices'         => array(
						'search'        => esc_html__( 'Search', 'reign' ),
						'cart'          => esc_html__( 'Cart', 'reign' ),
						'login'         => esc_html__( 'Login', 'reign' ),
						'register-menu' => esc_html__( 'Register', 'reign' ),
					),
					/* comment below to make layout meun icon section available for elementor header */
					'active_callback' => array(
						array(
							'setting'  => 'reign_header_header_type',
							'operator' => '!==',
							'value'    => true,
						),
					),
				);

			} elseif ( class_exists( 'BuddyPress' ) ) {

				$fields[] = array(
					'type'            => 'sortable',
					'settings'        => 'reign_mobile_header_icons_set',
					'label'           => esc_attr__( 'Mobile Header Icons Options', 'reign' ),
					'description'     => '',
					'section'         => 'reign_header_mobile_menu',
					'priority'        => 10,
					'default'         => $default_value_set['reign_mobile_header_icons_set'],
					'choices'         => array(
						'search'        => esc_html__( 'Search', 'reign' ),
						'message'       => esc_html__( 'Message', 'reign' ),
						'notification'  => esc_html__( 'Notification', 'reign' ),
						'login'         => esc_html__( 'Login', 'reign' ),
						'register-menu' => esc_html__( 'Register', 'reign' ),
					),
					/* comment below to make layout meun icon section available for elementor header */
					'active_callback' => array(
						array(
							'setting'  => 'reign_header_header_type',
							'operator' => '!==',
							'value'    => true,
						),
					),
				);

			} else {

				$fields[] = array(
					'type'            => 'sortable',
					'settings'        => 'reign_mobile_header_icons_set',
					'label'           => esc_attr__( 'Mobile Header Icons Options', 'reign' ),
					'description'     => '',
					'section'         => 'reign_header_mobile_menu',
					'priority'        => 10,
					'default'         => $default_value_set['reign_mobile_header_icons_set'],
					'choices'         => array(
						'search'        => esc_html__( 'Search', 'reign' ),
						'login'         => esc_html__( 'Login', 'reign' ),
						'register-menu' => esc_html__( 'Register', 'reign' ),
					),
					/* comment below to make layout meun icon section available for elementor header */
					'active_callback' => array(
						array(
							'setting'  => 'reign_header_header_type',
							'operator' => '!==',
							'value'    => true,
						),
					),
				);

			}

			return $fields;
		}

	}



endif;

/**
 * Main instance of Reign_Kirki_Header_Mobile_Menu.
 *
 * @return Reign_Kirki_Header_Mobile_Menu
 */
Reign_Kirki_Header_Mobile_Menu::instance();
