<?php

if ( !defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

if ( !class_exists( 'Reign_Kirki_Header_Topbar' ) ) :

	/**
	 * @class Reign_Kirki_Header_Topbar
	 */
	class Reign_Kirki_Header_Topbar {

		/**
		 * The single instance of the class.
		 *
		 * @var Reign_Kirki_Header_Topbar
		 */
		protected static $_instance = null;

		/**
		 * Main Reign_Kirki_Header_Topbar Instance.
		 *
		 * Ensures only one instance of Reign_Kirki_Header_Topbar is loaded or can be loaded.
		 *
		 * @return Reign_Kirki_Header_Topbar - Main instance.
		 */
		public static function instance() {
			if ( is_null( self::$_instance ) ) {
				self::$_instance = new self();
			}
			return self::$_instance;
		}

		/**
		 * Reign_Kirki_Header_Topbar Constructor.
		 */
		public function __construct() {
			$this->init_hooks();
		}

		/**
		 * Hook into actions and filters.
		 */
		private function init_hooks() {
			add_action( 'customize_register', array( $this, 'add_panels_and_sections' ) );
			add_filter( 'kirki/fields', array( $this, 'add_fields' ) );
		}

		public function add_panels_and_sections( $wp_customize ) {

			$wp_customize->add_section(
			'reign_header_topbar', array(
				'title'			 => __( 'Topbar', 'reign' ),
				'priority'		 => 10,
				'panel'			 => 'reign_header_panel',
				'description'	 => '',
			)
			);
		}

		public function add_fields( $fields ) {

			$default_value_set = reign_get_customizer_default_value_set();

			$fields[] = array(
				'type'			 => 'switch',
				'settings'		 => 'reign_header_topbar_enable',
				'label'			 => esc_attr__( 'Enable Topbar', 'reign' ),
				'description'	 => esc_attr__( 'Enable or Disable topbar.', 'reign' ),
				'section'		 => 'reign_header_topbar',
				'default'		 => 1,
				'priority'		 => 10,
				'choices'		 => array(
					'on'	 => esc_attr__( 'Enable', 'reign' ),
					'off'	 => esc_attr__( 'Disable', 'reign' ),
				),
			);

			$fields_on_hold		 = array();
                        $fields_on_hold[]	 = array(
				'type'				 => 'switch',
				'settings'			 => 'reign_header_topbar_sticky',
				'label'				 => esc_attr__( 'Sticky Topbar', 'reign' ),
				'description'		 => esc_attr__( 'Enable or Disable sticky topbar (desktop view).', 'reign' ),
				'section'			 => 'reign_header_topbar',
				'default'			 => 0,
				'priority'			 => 10,
				'choices'			 => array(
					'on'	 => esc_attr__( 'Enable', 'reign' ),
					'off'	 => esc_attr__( 'Disable', 'reign' ),
				),
				'active_callback'	 => array(
					array(
						'setting'	 => 'reign_header_topbar_enable',
						'operator'	 => '===',
						'value'		 => true,
					),
				),
			);
			$fields_on_hold[]	 = array(
				'type'				 => 'switch',
				'settings'			 => 'reign_header_topbar_mobile_view_disable',
				'label'				 => esc_attr__( 'Disable Topbar On Mobile', 'reign' ),
				'description'		 => esc_attr__( 'Disable topbar on mobile view.', 'reign' ),
				'section'			 => 'reign_header_topbar',
				'default'			 => 0,
				'priority'			 => 10,
				'choices'			 => array(
					'on'	 => esc_attr__( 'Enable', 'reign' ),
					'off'	 => esc_attr__( 'Disable', 'reign' ),
				),
				'active_callback'	 => array(
					array(
						'setting'	 => 'reign_header_topbar_enable',
						'operator'	 => '===',
						'value'		 => true,
					),
				),
			);
			$fields_on_hold[]	 = array(
				'type'				 => 'repeater',
				'settings'			 => 'reign_header_topbar_info_links',
				'label'				 => esc_attr__( 'Info Links', 'reign' ),
				'description'		 => __( 'Fontawesome classes are used to set icons. Check <a href="https://fontawesome.com/icons" target="_blank">https://fontawesome.com/</a> for further assistance.', 'reign' ),
				'section'			 => 'reign_header_topbar',
				'priority'			 => 13,
				'row_label'			 => array(
					'type'	 => 'field',
					'value'	 => esc_attr__( 'Info Link', 'reign' ),
					'field'	 => 'link_text',
				),
				'button_label'		 => esc_attr__( 'Add', 'reign' ),
				'transport'			 => 'postMessage',
				'default'			 => $default_value_set[ 'reign_header_topbar_info_links' ],
				'fields'			 => array(
					'link_text'	 => array(
						'type'			 => 'text',
						'label'			 => esc_attr__( 'Title', 'reign' ),
						'description'	 => '',
						'default'		 => '',
					),
					'link_icon'	 => array(
						'type'			 => 'textarea',
						'label'			 => esc_attr__( 'Icon', 'reign' ),
						'description'	 => '',
						'default'		 => '',
					),
					'link_url'	 => array(
						'type'			 => 'text',
						'label'			 => esc_attr__( 'Link', 'reign' ),
						'description'	 => '',
						'default'		 => '',
					),
				),
				'active_callback'	 => array(
					array(
						'setting'	 => 'reign_header_topbar_enable',
						'operator'	 => '===',
						'value'		 => true,
					),
				),
			);

			$fields_on_hold[] = array(
				'type'				 => 'repeater',
				'settings'			 => 'reign_header_topbar_social_links',
				'label'				 => esc_attr__( 'Social Links', 'reign' ),
				'description'		 => __( 'Fontawesome classes are used to set icons. Check <a href="https://fontawesome.com/icons" target="_blank">https://fontawesome.com/</a> for further assistance.', 'reign' ),
				'section'			 => 'reign_header_topbar',
				'priority'			 => 13,
				'row_label'			 => array(
					'type'	 => 'field',
					'value'	 => esc_attr__( 'Social Link', 'reign' ),
					'field'	 => 'link_text',
				),
				'button_label'		 => esc_attr__( 'Add', 'reign' ),
				'transport'			 => 'postMessage',
				'default'			 => $default_value_set[ 'reign_header_topbar_social_links' ],
				'fields'			 => array(
					'link_text'	 => array(
						'type'			 => 'text',
						'label'			 => esc_attr__( 'Title', 'reign' ),
						'description'	 => '',
						'default'		 => '',
					),
					'link_icon'	 => array(
						'type'			 => 'textarea',
						'label'			 => esc_attr__( 'Icon', 'reign' ),
						'description'	 => '',
						'default'		 => '<i class="fab fa-facebook"></i>',
					),
					'link_url'	 => array(
						'type'			 => 'url',
						'label'			 => esc_attr__( 'Link', 'reign' ),
						'description'	 => '',
						'default'		 => '',
					),
				),
				'active_callback'	 => array(
					array(
						'setting'	 => 'reign_header_topbar_enable',
						'operator'	 => '===',
						'value'		 => true,
					),
				),
			);

			$fields_on_hold = apply_filters( 'reign_header_topbar_fields_on_hold', $fields_on_hold );

			foreach ( $fields_on_hold as $key => $value ) {
				$fields[] = $value;
			}

			return $fields;
		}

	}

	endif;

/**
 * Main instance of Reign_Kirki_Header_Topbar.
 * @return Reign_Kirki_Header_Topbar
 */
Reign_Kirki_Header_Topbar::instance();
