<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

if ( ! class_exists( 'Reign_Kirki_Left_Panel' ) ) :

	/**
	 * @class Reign_Kirki_Left_Panel
	 */
	class Reign_Kirki_Left_Panel {

		/**
		 * The single instance of the class.
		 *
		 * @var Reign_Kirki_Left_Panel
		 */
		protected static $_instance = null;

		/**
		 * Main Reign_Kirki_Left_Panel Instance.
		 *
		 * Ensures only one instance of Reign_Kirki_Left_Panel is loaded or can be loaded.
		 *
		 * @return Reign_Kirki_Left_Panel - Main instance.
		 */
		public static function instance() {
			if ( is_null( self::$_instance ) ) {
				self::$_instance = new self();
			}
			return self::$_instance;
		}

		/**
		 * Reign_Kirki_Left_Panel Constructor.
		 */
		public function __construct() {
			$this->init_hooks();
		}

		/**
		 * Hook into actions and filters.
		 */
		private function init_hooks() {
			add_action( 'customize_register', array( $this, 'add_panels_and_sections' ) );
			add_filter( 'kirki/fields', array( $this, 'add_fields' ) );
		}

		public function add_panels_and_sections( $wp_customize ) {

			$wp_customize->add_section(
				'reign_left_section',
				array(
					'priority'    => 80,
					'title'       => __( 'Left Panel', 'reign' ),
					'panel'       => 'reign_header_panel',
					'description' => '',
				)
			);

		}

		public function add_fields( $fields ) {

			$fields[] = array(
				'type'     => 'radio-buttonset',
				'settings' => 'reign_left_panel_position',
				'label'    => esc_html__( 'Left Panel Position', 'reign' ),
				'section'  => 'reign_left_section',
				'default'  => 'left',
				'priority' => 10,
				'choices'  => array(
					'left'  => esc_html__( 'Left', 'reign' ),
					'right' => esc_html__( 'Right', 'reign' ),
				),
			);

			$fields[] = array(
				'type'     => 'switch',
				'settings' => 'reign_left_panel_logout_mode',
				'label'    => esc_html__( 'Left Panel - Logout Mode', 'reign' ),
				'section'  => 'reign_left_section',
				'default'  => 'on',
				'priority' => 10,
				'choices'  => array(
					'on'  => esc_html__( 'Enable', 'reign' ),
					'off' => esc_html__( 'Disable', 'reign' ),
				),
			);

			$fields[] = array(
				'type'     => 'switch',
				'settings' => 'reign_left_panel_toggle',
				'label'    => esc_html__( 'Left Panel - Toggle', 'reign' ),
				'section'  => 'reign_left_section',
				'default'  => 'on',
				'priority' => 10,
				'choices'  => array(
					'on'  => esc_html__( 'Enable', 'reign' ),
					'off' => esc_html__( 'Disable', 'reign' ),
				),
			);

			$fields[] = array(
				'type'     => 'radio-buttonset',
				'settings' => 'reign_left_panel_state',
				'label'    => esc_html__( 'Left Panel - Default State', 'reign' ),
				'section'  => 'reign_left_section',
				'default'  => 'closed',
				'priority' => 10,
				'choices'  => array(
					'open'   => esc_html__( 'Open', 'reign' ),
					'closed' => esc_html__( 'Closed', 'reign' ),
				),
			);

			return $fields;
		}

	}

	endif;


/**
 * Main instance of Reign_Kirki_Left_Panel.
 *
 * @return Reign_Kirki_Left_Panel
 */
Reign_Kirki_Left_Panel::instance();
